@@ -18,12 +18,18 @@ function checkout_from {
   cd ../
 }
 
+removeFolderWithProtectedFiles() {
+  find $1 -delete
+}
+
 case $1 in
 
 sonarqube)
   # token could be generated at https://sonarcloud.io/account/security/
-  # executon on local:
-  # SONAR_TOKEN=xxxxxx PR=xxxxxx WERCKER_GIT_BRANCH=xxxxxx ./.ci/travis/travis.sh sonarqube
+  # executon on local for master:
+  # SONAR_TOKEN=xxxxxx ./.ci/wercker.sh sonarqube
+  # executon on local for non-master:
+  # SONAR_TOKEN=xxxxxx PR=xxxxxx WERCKER_GIT_BRANCH=xxxxxx ./.ci/wercker.sh sonarqube
   if [[ $PR && $PR =~ ^([0-9]*)$ ]]; then
       SONAR_PR_VARIABLES="-Dsonar.pullrequest.key=$PR"
       SONAR_PR_VARIABLES+=" -Dsonar.pullrequest.branch=$WERCKER_GIT_BRANCH"
@@ -43,8 +49,11 @@ sonarqube)
   checkout_from https://github.com/viesure/blog-sonar-build-breaker.git
   sed -i'' "s|our.sonar.server|sonarcloud.io|" \
     .ci-temp/blog-sonar-build-breaker/sonar_break_build.sh
+  sed -i'' "s|curl |curl -k |" \
+    .ci-temp/blog-sonar-build-breaker/sonar_break_build.sh
   export SONAR_API_TOKEN=$SONAR_TOKEN
   .ci-temp/blog-sonar-build-breaker/sonar_break_build.sh
+  removeFolderWithProtectedFiles .ci-temp/blog-sonar-build-breaker
   ;;
 
 
@@ -53,10 +62,11 @@ no-error-pgjdbc)
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: ${CS_POM_VERSION}
   checkout_from https://github.com/pgjdbc/pgjdbc.git
-  cd .ci-temp/pgjdbc/pgjdbc
-  mvn -e checkstyle:check -Dcheckstyle.version=${CS_POM_VERSION}
-  cd ../../
-  rm -rf pgjdbc
+  cd .ci-temp/pgjdbc
+  ./gradlew --no-parallel --no-daemon checkstyleAll \
+            -PenableMavenLocal -Pcheckstyle.version=${CS_POM_VERSION}
+  cd ../
+ removeFolderWithProtectedFiles pgjdbc
   ;;
 
 no-error-orekit)
@@ -66,19 +76,20 @@ no-error-orekit)
   checkout_from https://github.com/Hipparchus-Math/hipparchus.git
   cd .ci-temp/hipparchus
   # checkout to version that Orekit expects
-  SHA_HIPPARCHUS="4c6c6fc45e859e""ae2d4eb091a3a3c0a7a458b8d9"
+  SHA_HIPPARCHUS="1fb""fb8a2a259a9""7a23e2a387e8fd""c5e0a8402e77"
   git checkout $SHA_HIPPARCHUS
-  mvn install -DskipTests
+  mvn -e install -DskipTests
   cd -
   checkout_from https://github.com/CS-SI/Orekit.git
   cd .ci-temp/Orekit
   # no CI is enforced in project, so to make our build stable we should
   # checkout to latest release/development (annotated tag or hash) or sha that have fix we need
   # git checkout $(git describe --abbrev=0 --tags)
-  git checkout "a7e67ce73803c67a""ad90e0b28ed77a7781dc28a9"
+  git checkout "b67b419db7014f4b""ad921a1ba""c6c848384ad2b92"
   mvn -e compile checkstyle:check -Dorekit.checkstyle.version=${CS_POM_VERSION}
-  cd ../
-  rm -rf Orekit
+  cd ..
+  removeFolderWithProtectedFiles Orekit
+  removeFolderWithProtectedFiles hipparchus
   ;;
 
 no-error-xwiki)
@@ -87,22 +98,24 @@ no-error-xwiki)
   echo CS_version: ${CS_POM_VERSION}
   checkout_from https://github.com/xwiki/xwiki-commons.git
   cd .ci-temp/xwiki-commons
-  mvn -f xwiki-commons-tools/xwiki-commons-tool-verification-resources/pom.xml \
+  SHA_XWIKI="4fa""a8a49de3a70b""ba9c6c3849784e5d""fb642fa8d"
+  git checkout $SHA_XWIKI
+  mvn -e -f xwiki-commons-tools/xwiki-commons-tool-verification-resources/pom.xml \
     install -DskipTests -Dcheckstyle.version=${CS_POM_VERSION}
   mvn -e test-compile checkstyle:check@default -Dcheckstyle.version=${CS_POM_VERSION}
-  cd ../../
-  rm -rf xwiki-commons
+  cd ..
+  removeFolderWithProtectedFiles xwiki-commons
   ;;
 
 no-error-apex-core)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: ${CS_POM_VERSION}
-  checkout_from https://github.com/apache/incubator-apex-core.git
-  cd .ci-temp/incubator-apex-core
+  checkout_from https://github.com/checkstyle/apex-core
+  cd .ci-temp/apex-core
   mvn -e compile checkstyle:check -Dcheckstyle.version=${CS_POM_VERSION}
   cd ../
-  rm -rf incubator-apex-core
+  removeFolderWithProtectedFiles apex-core
   ;;
 
 no-error-equalsverifier)
@@ -113,7 +126,7 @@ no-error-equalsverifier)
   cd .ci-temp/equalsverifier
   mvn -e compile checkstyle:check -Dcheckstyle.version=${CS_POM_VERSION}
   cd ../
-  rm -rf equalsverifier
+  removeFolderWithProtectedFiles equalsverifier
   ;;
 
 no-error-hibernate-search)
@@ -127,21 +140,18 @@ no-error-hibernate-search)
      -Dpuppycrawl.checkstyle.version=${CS_POM_VERSION}
   mvn -e checkstyle:check  -Dpuppycrawl.checkstyle.version=${CS_POM_VERSION}
   cd ../
-  rm -rf hibernate-search
+  removeFolderWithProtectedFiles hibernate-search
   ;;
 
 no-error-htmlunit)
   CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
   echo CS_version: ${CS_POM_VERSION}
-  echo "checkouting project sources ..."
-  svn -q export https://svn.code.sf.net/p/htmlunit/code/trunk/htmlunit@r14923 htmlunit
-  cd htmlunit
- sed -i "s/            <version>2.28-SNAPSHOT/            <version>2.28-20171106.080245-12/" pom.xml
-  echo "Running checkstyle validation ..."
+  checkout_from https://github.com/HtmlUnit/htmlunit
+  cd .ci-temp/htmlunit
   mvn -e compile checkstyle:check -Dcheckstyle.version=${CS_POM_VERSION}
   cd ../
-  rm -rf htmlunit
+  removeFolderWithProtectedFiles htmlunit
   ;;
 
 no-error-checkstyles-sevntu)
@@ -164,7 +174,38 @@ no-error-sevntu-checks)
   mvn -e -Pno-validations verify  -Dcheckstyle.skip=false -Dcheckstyle.version=${CS_POM_VERSION} \
      -Dcheckstyle.configLocation=../../../config/checkstyle_checks.xml
   cd ../../
-  rm -rf sevntu.checkstyle
+  removeFolderWithProtectedFiles sevntu.checkstyle
+  ;;
+
+no-error-contribution)
+  set -e
+  CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
+                     --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
+  echo CS_version: ${CS_POM_VERSION}
+  checkout_from https://github.com/checkstyle/contribution.git
+  cd .ci-temp/contribution
+  cd patch-diff-report-tool
+  mvn -e verify -DskipTests -Dcheckstyle.version=${CS_POM_VERSION} \
+     -Dcheckstyle.configLocation=../../../config/checkstyle_checks.xml
+  cd ../
+  cd releasenotes-builder
+  mvn -e verify -DskipTests -Dcheckstyle.version=${CS_POM_VERSION} \
+     -Dcheckstyle.configLocation=../../../config/checkstyle_checks.xml
+  cd ../../
+  removeFolderWithProtectedFiles contribution
+  ;;
+
+no-error-methods-distance)
+  set -e
+  CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
+                     --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
+  echo CS_version: ${CS_POM_VERSION}
+  checkout_from https://github.com/sevntu-checkstyle/methods-distance.git
+  cd .ci-temp/methods-distance
+  mvn -e verify -DskipTests -Dcheckstyle-version=${CS_POM_VERSION} \
+     -Dcheckstyle.configLocation=../../config/checkstyle_checks.xml
+  cd ..
+  removeFolderWithProtectedFiles  methods-distance
   ;;
 
 no-error-strata)
@@ -176,11 +217,11 @@ no-error-strata)
   cd .ci-temp/Strata
   STRATA_CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${checkstyle.version}' \
                      --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
-  mvn install -e -B -Dstrict -DskipTests \
+  mvn -e install -B -Dstrict -DskipTests \
      -Dforbiddenapis.skip=true -Dcheckstyle.version=${CS_POM_VERSION} \
      -Dcheckstyle.config.suffix="-v$STRATA_CS_POM_VERSION"
   cd ../
-  rm -rf Strata
+  removeFolderWithProtectedFiles Strata
   ;;
 
 no-error-spring-integration)
@@ -194,7 +235,7 @@ no-error-spring-integration)
   PROP_CS_VERSION="checkstyleVersion"
   ./gradlew clean check --parallel -x test -P$PROP_MAVEN_LOCAL -P$PROP_CS_VERSION=${CS_POM_VERSION}
   cd ../
-  rm -rf spring-integration
+  removeFolderWithProtectedFiles spring-integration
   ;;
 
 no-exception-struts)
@@ -208,7 +249,7 @@ no-exception-struts)
   groovy ./launch.groovy --listOfProjects projects-for-wercker.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
   ;;
 
 no-exception-checkstyle-sevntu)
@@ -224,7 +265,23 @@ no-exception-checkstyle-sevntu)
   groovy ./launch.groovy --listOfProjects projects-for-wercker.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
+  ;;
+
+no-exception-checkstyle-sevntu-javadoc)
+  set -e
+  CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
+                     --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
+  echo CS_version: ${CS_POM_VERSION}
+  checkout_from https://github.com/checkstyle/contribution.git
+  cd .ci-temp/contribution/checkstyle-tester
+  sed -i'' 's/^guava/#guava/' projects-for-wercker.properties
+  sed -i'' 's/#local-checkstyle/local-checkstyle/' projects-for-wercker.properties
+  sed -i'' 's/#sevntu-checkstyle/sevntu-checkstyle/' projects-for-wercker.properties
+  groovy ./launch.groovy --listOfProjects projects-for-wercker.properties \
+      --config checks-only-javadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
+  cd ../../
+  removeFolderWithProtectedFiles contribution
   ;;
 
 no-exception-guava)
@@ -238,7 +295,7 @@ no-exception-guava)
   groovy ./launch.groovy --listOfProjects projects-for-wercker.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
   ;;
 
 no-exception-hibernate-orm)
@@ -252,7 +309,7 @@ no-exception-hibernate-orm)
   groovy ./launch.groovy --listOfProjects projects-for-wercker.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
   ;;
 
 no-exception-spotbugs)
@@ -266,7 +323,21 @@ no-exception-spotbugs)
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
+  ;;
+
+no-exception-spoon)
+  CS_POM_VERSION=$(mvn -e -q -Dexec.executable='echo' -Dexec.args='${project.version}' \
+                     --non-recursive org.codehaus.mojo:exec-maven-plugin:1.3.1:exec)
+  echo CS_version: ${CS_POM_VERSION}
+  checkout_from https://github.com/checkstyle/contribution.git
+  cd .ci-temp/contribution/checkstyle-tester
+  sed -i.'' 's/^guava/#guava/' projects-to-test-on.properties
+  sed -i.'' 's/#spoon/spoon/' projects-to-test-on.properties
+  groovy ./launch.groovy --listOfProjects projects-for-wercker.properties \
+      --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
+  cd ../../
+  removeFolderWithProtectedFiles contribution
   ;;
 
 no-exception-spring-framework)
@@ -280,7 +351,7 @@ no-exception-spring-framework)
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
   ;;
 
 no-exception-hbase)
@@ -294,7 +365,7 @@ no-exception-hbase)
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
   ;;
 
 no-exception-Pmd-elasticsearch-lombok-ast)
@@ -310,7 +381,7 @@ no-exception-Pmd-elasticsearch-lombok-ast)
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
   ;;
 
 no-exception-alot-of-projects)
@@ -329,7 +400,7 @@ no-exception-alot-of-projects)
   groovy ./launch.groovy --listOfProjects projects-to-test-on.properties \
       --config checks-nonjavadoc-error.xml --checkstyleVersion ${CS_POM_VERSION}
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
   ;;
 
 no-warning-imports-guava)
@@ -345,7 +416,7 @@ no-warning-imports-guava)
       --checkstyleVersion ${CS_POM_VERSION}
   RESULT=`grep -A 5 "&#160;Warning</td>" $REPORT | cat`
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
   if [ -z "$RESULT" ]; then
     echo "Inspection did not find any warnings"
   else
@@ -369,7 +440,7 @@ no-warning-imports-java-design-patterns)
       --checkstyleVersion ${CS_POM_VERSION}
   RESULT=`grep -A 5 "&#160;Warning</td>" $REPORT | cat`
   cd ../../
-  rm -rf contribution
+  removeFolderWithProtectedFiles contribution
   if [ -z "$RESULT" ]; then
     echo "Inspection did not find any warnings"
   else
@@ -380,6 +451,28 @@ no-warning-imports-java-design-patterns)
   fi
   ;;
 
+validate-ci-temp-empty)
+  fail=0
+  if [ -z "$(ls -A .ci-temp)" ]; then
+    echo "Empty .ci-temp/ validation did not find any warnings."
+  else
+    echo "Directory .ci-temp/ is not empty. Verification failed."
+    echo "Contents of .ci-temp/:"
+    fail=1
+  fi
+  ls -A .ci-temp --color=auto
+  exit $fail
+  ;;
+
+git-status)
+  if [ "$(git status | grep 'Changes not staged\|Untracked files')" ]; then
+    printf "Please clean up or update .gitattributes file.\nGit status output:\n"
+    git status
+    sleep 5s
+    false
+  fi
+  ;;
+
 *)
   echo "Unexpected argument: $1"
   sleep 5s
