@@ -105,12 +105,6 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 public class SuppressWarningsHolder
     extends AbstractCheck {
 
-    /**
-     * A key is pointing to the warning message text in "messages.properties"
-     * file.
-     */
-    public static final String MSG_KEY = "suppress.warnings.invalid.target";
-
     /**
      * Optional prefix for warning suppressions that are only intended to be
      * recognized by checkstyle. For instance, to suppress {@code
@@ -143,6 +137,7 @@ public class SuppressWarningsHolder
      * Returns the default alias for the source name of a check, which is the
      * source name in lower case with any dotted prefix or "Check" suffix
      * removed.
+     *
      * @param sourceName the source name of the check (generally the class
      *        name)
      * @return the default alias for the given check
@@ -160,6 +155,7 @@ public class SuppressWarningsHolder
      * Returns the alias for the source name of a check. If an alias has been
      * explicitly registered via {@link #setAliasList(String...)}, that
      * alias is returned; otherwise, the default alias is used.
+     *
      * @param sourceName the source name of the check (generally the class
      *        name)
      * @return the current alias for the given check
@@ -174,6 +170,7 @@ public class SuppressWarningsHolder
 
     /**
      * Registers an alias for the source name of a check.
+     *
      * @param sourceName the source name of the check (generally the class
      *        name)
      * @param checkAlias the alias used in {@link SuppressWarnings} annotations
@@ -185,6 +182,7 @@ public class SuppressWarningsHolder
     /**
      * Setter to specify aliases for check names that can be used in code
      * within {@code SuppressWarnings}.
+     *
      * @param aliasList the list of comma-separated alias assignments
      * @throws IllegalArgumentException when alias item does not have '='
      */
@@ -205,6 +203,7 @@ public class SuppressWarningsHolder
     /**
      * Checks for a suppression of a check with the given source name and
      * location in the last file processed.
+     *
      * @param event audit event.
      * @return whether the check with the given name is suppressed at the given
      *         source location
@@ -235,6 +234,7 @@ public class SuppressWarningsHolder
     /**
      * Checks whether suppression entry position is after the audit event occurrence position
      * in the source file.
+     *
      * @param line the line number in the source file where the event occurred.
      * @param column the column number in the source file where the event occurred.
      * @param entry suppression entry.
@@ -250,6 +250,7 @@ public class SuppressWarningsHolder
     /**
      * Checks whether suppression entry position is before the audit event occurrence position
      * in the source file.
+     *
      * @param line the line number in the source file where the event occurred.
      * @param column the column number in the source file where the event occurred.
      * @param entry suppression entry.
@@ -295,34 +296,29 @@ public class SuppressWarningsHolder
             if (!isAnnotationEmpty(values)) {
                 final DetailAST targetAST = getAnnotationTarget(ast);
 
-                if (targetAST == null) {
-                    log(ast.getLineNo(), MSG_KEY);
+                // get text range of target
+                final int firstLine = targetAST.getLineNo();
+                final int firstColumn = targetAST.getColumnNo();
+                final DetailAST nextAST = targetAST.getNextSibling();
+                final int lastLine;
+                final int lastColumn;
+                if (nextAST == null) {
+                    lastLine = Integer.MAX_VALUE;
+                    lastColumn = Integer.MAX_VALUE;
                 }
                 else {
-                    // get text range of target
-                    final int firstLine = targetAST.getLineNo();
-                    final int firstColumn = targetAST.getColumnNo();
-                    final DetailAST nextAST = targetAST.getNextSibling();
-                    final int lastLine;
-                    final int lastColumn;
-                    if (nextAST == null) {
-                        lastLine = Integer.MAX_VALUE;
-                        lastColumn = Integer.MAX_VALUE;
-                    }
-                    else {
-                        lastLine = nextAST.getLineNo();
-                        lastColumn = nextAST.getColumnNo() - 1;
-                    }
+                    lastLine = nextAST.getLineNo();
+                    lastColumn = nextAST.getColumnNo() - 1;
+                }
 
-                    // add suppression entries for listed checks
-                    final List<Entry> entries = ENTRIES.get();
-                    for (String value : values) {
-                        String checkName = value;
-                        // strip off the checkstyle-only prefix if present
-                        checkName = removeCheckstylePrefixIfExists(checkName);
-                        entries.add(new Entry(checkName, firstLine, firstColumn,
-                                lastLine, lastColumn));
-                    }
+                // add suppression entries for listed checks
+                final List<Entry> entries = ENTRIES.get();
+                for (String value : values) {
+                    String checkName = value;
+                    // strip off the checkstyle-only prefix if present
+                    checkName = removeCheckstylePrefixIfExists(checkName);
+                    entries.add(new Entry(checkName, firstLine, firstColumn,
+                            lastLine, lastColumn));
                 }
             }
         }
@@ -345,6 +341,7 @@ public class SuppressWarningsHolder
 
     /**
      * Get all annotation values.
+     *
      * @param ast annotation token
      * @return list values
      */
@@ -381,6 +378,7 @@ public class SuppressWarningsHolder
 
     /**
      * Checks that annotation is empty.
+     *
      * @param values list of values in the annotation
      * @return whether annotation is empty or contains some values
      */
@@ -390,6 +388,7 @@ public class SuppressWarningsHolder
 
     /**
      * Get target of annotation.
+     *
      * @param ast the AST node to get the child of
      * @return get target of annotation
      */
@@ -399,7 +398,9 @@ public class SuppressWarningsHolder
         switch (parentAST.getType()) {
             case TokenTypes.MODIFIERS:
             case TokenTypes.ANNOTATIONS:
-                targetAST = getAcceptableParent(parentAST);
+            case TokenTypes.ANNOTATION:
+            case TokenTypes.ANNOTATION_MEMBER_VALUE_PAIR:
+                targetAST = parentAST.getParent();
                 break;
             default:
                 // unexpected container type
@@ -408,46 +409,9 @@ public class SuppressWarningsHolder
         return targetAST;
     }
 
-    /**
-     * Returns parent of given ast if parent has one of the following types:
-     * ANNOTATION_DEF, PACKAGE_DEF, CLASS_DEF, ENUM_DEF, ENUM_CONSTANT_DEF, CTOR_DEF,
-     * METHOD_DEF, PARAMETER_DEF, VARIABLE_DEF, ANNOTATION_FIELD_DEF, TYPE, LITERAL_NEW,
-     * LITERAL_THROWS, TYPE_ARGUMENT, IMPLEMENTS_CLAUSE, DOT.
-     * @param child an ast
-     * @return returns ast - parent of given
-     */
-    private static DetailAST getAcceptableParent(DetailAST child) {
-        final DetailAST result;
-        final DetailAST parent = child.getParent();
-        switch (parent.getType()) {
-            case TokenTypes.ANNOTATION_DEF:
-            case TokenTypes.PACKAGE_DEF:
-            case TokenTypes.CLASS_DEF:
-            case TokenTypes.INTERFACE_DEF:
-            case TokenTypes.ENUM_DEF:
-            case TokenTypes.ENUM_CONSTANT_DEF:
-            case TokenTypes.CTOR_DEF:
-            case TokenTypes.METHOD_DEF:
-            case TokenTypes.PARAMETER_DEF:
-            case TokenTypes.VARIABLE_DEF:
-            case TokenTypes.ANNOTATION_FIELD_DEF:
-            case TokenTypes.TYPE:
-            case TokenTypes.LITERAL_NEW:
-            case TokenTypes.LITERAL_THROWS:
-            case TokenTypes.TYPE_ARGUMENT:
-            case TokenTypes.IMPLEMENTS_CLAUSE:
-            case TokenTypes.DOT:
-                result = parent;
-                break;
-            default:
-                // it's possible case, but shouldn't be processed here
-                result = null;
-        }
-        return result;
-    }
-
     /**
      * Returns the n'th child of an AST node.
+     *
      * @param ast the AST node to get the child of
      * @param index the index of the child to get
      * @return the n'th child of the given AST node, or {@code null} if none
@@ -462,6 +426,7 @@ public class SuppressWarningsHolder
 
     /**
      * Returns the Java identifier represented by an AST.
+     *
      * @param ast an AST node for an IDENT or DOT
      * @return the Java identifier represented by the given AST subtree
      * @throws IllegalArgumentException if the AST is invalid
@@ -483,6 +448,7 @@ public class SuppressWarningsHolder
 
     /**
      * Returns the literal string expression represented by an AST.
+     *
      * @param ast an AST node for an EXPR
      * @return the Java string represented by the given AST expression
      *         or empty string if expression is too complex
@@ -512,6 +478,7 @@ public class SuppressWarningsHolder
 
     /**
      * Returns the annotation values represented by an AST.
+     *
      * @param ast an AST node for an EXPR or ANNOTATION_ARRAY_INIT
      * @return the list of Java string represented by the given AST for an
      *         expression or annotation array initializer
@@ -535,6 +502,7 @@ public class SuppressWarningsHolder
 
     /**
      * Method looks at children and returns list of expressions in strings.
+     *
      * @param parent ast, that contains children
      * @return list of expressions in strings
      */
@@ -572,6 +540,7 @@ public class SuppressWarningsHolder
 
         /**
          * Constructs a new suppression region entry.
+         *
          * @param checkName the source name of the suppressed check
          * @param firstLine the first line of the suppression region
          * @param firstColumn the first column of the suppression region
@@ -589,6 +558,7 @@ public class SuppressWarningsHolder
 
         /**
          * Gets he source name of the suppressed check.
+         *
          * @return the source name of the suppressed check
          */
         public String getCheckName() {
@@ -597,6 +567,7 @@ public class SuppressWarningsHolder
 
         /**
          * Gets the first line of the suppression region.
+         *
          * @return the first line of the suppression region
          */
         public int getFirstLine() {
@@ -605,6 +576,7 @@ public class SuppressWarningsHolder
 
         /**
          * Gets the first column of the suppression region.
+         *
          * @return the first column of the suppression region
          */
         public int getFirstColumn() {
@@ -613,6 +585,7 @@ public class SuppressWarningsHolder
 
         /**
          * Gets the last line of the suppression region.
+         *
          * @return the last line of the suppression region
          */
         public int getLastLine() {
@@ -621,6 +594,7 @@ public class SuppressWarningsHolder
 
         /**
          * Gets the last column of the suppression region.
+         *
          * @return the last column of the suppression region
          */
         public int getLastColumn() {
