@@ -29,6 +29,7 @@ import com.puppycrawl.tools.checkstyle.api.DetailAST;
 import com.puppycrawl.tools.checkstyle.api.TokenTypes;
 import com.puppycrawl.tools.checkstyle.utils.CheckUtil;
 import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
+import com.puppycrawl.tools.checkstyle.utils.TokenUtil;
 
 /**
  * <p>
@@ -36,8 +37,11 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * if-else, try-catch-finally blocks, while-loops, for-loops,
  * method definitions, class definitions, constructor definitions,
  * instance, static initialization blocks, annotation definitions and enum definitions.
- * For right curly brace of expression blocks please follow issue
+ * For right curly brace of expression blocks of arrays, lambdas and class instances
+ * please follow issue
  * <a href="https://github.com/checkstyle/checkstyle/issues/5945">#5945</a>.
+ * For right curly brace of enum constant please follow issue
+ * <a href="https://github.com/checkstyle/checkstyle/issues/7519">#7519</a>.
  * </p>
  * <ul>
  * <li>
@@ -67,6 +71,51 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * &lt;module name="RightCurly"/&gt;
  * </pre>
  * <p>
+ * Example:
+ * </p>
+ * <pre>
+ * public class Test {
+ *
+ *   public void test() {
+ *
+ *     if (foo) {
+ *       bar();
+ *     }           // violation, right curly must be in the same line as the 'else' keyword
+ *     else {
+ *       bar();
+ *     }
+ *
+ *     if (foo) {
+ *       bar();
+ *     } else {     // OK
+ *       bar();
+ *     }
+ *
+ *     if (foo) { bar(); } int i = 0; // violation
+ *                   // ^^^ statement is not allowed on same line after curly right brace
+ *
+ *     if (foo) { bar(); }            // OK
+ *     int i = 0;
+ *
+ *     try {
+ *       bar();
+ *     }           // violation, rightCurly must be in the same line as 'catch' keyword
+ *     catch (Exception e) {
+ *       bar();
+ *     }
+ *
+ *     try {
+ *       bar();
+ *     } catch (Exception e) { // OK
+ *       bar();
+ *     }
+ *
+ *   }                         // OK
+ *
+ *   public void testSingleLine() { bar(); } // OK, because singleline is allowed
+ * }
+ * </pre>
+ * <p>
  * To configure the check with policy {@code alone} for {@code else} and
  * <a href="https://checkstyle.org/apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#METHOD_DEF">
  * METHOD_DEF</a> tokens:
@@ -77,9 +126,85 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  *   &lt;property name=&quot;tokens&quot; value=&quot;LITERAL_ELSE, METHOD_DEF&quot;/&gt;
  * &lt;/module&gt;
  * </pre>
+ * <p>
+ * Example:
+ * </p>
+ * <pre>
+ * public class Test {
+ *
+ *   public void test() {
+ *
+ *     if (foo) {
+ *       bar();
+ *     } else { bar(); }   // violation, right curly must be alone on line
+ *
+ *     if (foo) {
+ *       bar();
+ *     } else {
+ *       bar();
+ *     }                   // OK
+ *
+ *     try {
+ *       bar();
+ *     } catch (Exception e) { // OK because config is set to token METHOD_DEF and LITERAL_ELSE
+ *       bar();
+ *     }
+ *
+ *   }                         // OK
+ *
+ *   public void violate() { bar; } // violation, singleline is not allowed here
+ *
+ *   public void ok() {
+ *     bar();
+ *   }                              // OK
+ * }
+ * </pre>
+ * <p>
+ * To configure the check with policy {@code alone_or_singleline} for {@code if}
+ * and <a href="apidocs/com/puppycrawl/tools/checkstyle/api/TokenTypes.html#METHOD_DEF">
+ * METHOD_DEF</a>
+ * tokens:
+ * </p>
+ * <pre>
+ * &lt;module name=&quot;RightCurly&quot;&gt;
+ *  &lt;property name=&quot;option&quot; value=&quot;alone_or_singleline&quot;/&gt;
+ *  &lt;property name=&quot;tokens&quot; value=&quot;LITERAL_IF, METHOD_DEF&quot;/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>
+ * Example:
+ * </p>
+ * <pre>
+ * public class Test {
+ *
+ *   public void test() {
+ *
+ *     if (foo) {
+ *       bar();
+ *     } else {        // violation, right curly must be alone on line
+ *       bar();
+ *     }
+ *
+ *     if (foo) {
+ *       bar();
+ *     }               // OK
+ *     else {
+ *       bar();
+ *     }
+ *
+ *     try {
+ *       bar();
+ *     } catch (Exception e) {        // OK because config did not set token LITERAL_TRY
+ *       bar();
+ *     }
+ *
+ *   }                                // OK
+ *
+ *   public void violate() { bar(); } // OK , because singleline
+ * }
+ * </pre>
  *
  * @since 3.0
- *
  */
 @StatelessCheck
 public class RightCurlyCheck extends AbstractCheck {
@@ -109,6 +234,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
     /**
      * Setter to specify the policy on placement of a right curly brace (<code>'}'</code>).
+     *
      * @param optionStr string to decode option from
      * @throws IllegalArgumentException if unable to decode
      */
@@ -145,6 +271,7 @@ public class RightCurlyCheck extends AbstractCheck {
             TokenTypes.INSTANCE_INIT,
             TokenTypes.ANNOTATION_DEF,
             TokenTypes.ENUM_DEF,
+            TokenTypes.INTERFACE_DEF,
         };
     }
 
@@ -168,6 +295,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
     /**
      * Does general validation.
+     *
      * @param details for validation.
      * @return violation message or empty string
      *     if there was not violation during validation.
@@ -188,6 +316,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
     /**
      * Checks whether a right curly should have a line break before.
+     *
      * @param bracePolicy option for placing the right curly brace.
      * @param details details for validation.
      * @return true if a right curly should have a line break before.
@@ -196,11 +325,12 @@ public class RightCurlyCheck extends AbstractCheck {
                                                      Details details) {
         return bracePolicy == RightCurlyOption.SAME
                 && !hasLineBreakBefore(details.rcurly)
-                && details.lcurly.getLineNo() != details.rcurly.getLineNo();
+                && !TokenUtil.areOnSameLine(details.lcurly, details.rcurly);
     }
 
     /**
      * Checks that a right curly should be on the same line as the next statement.
+     *
      * @param bracePolicy option for placing the right curly brace
      * @param details Details for validation
      * @return true if a right curly should be alone on a line.
@@ -208,11 +338,12 @@ public class RightCurlyCheck extends AbstractCheck {
     private static boolean shouldBeOnSameLine(RightCurlyOption bracePolicy, Details details) {
         return bracePolicy == RightCurlyOption.SAME
                 && !details.shouldCheckLastRcurly
-                && details.rcurly.getLineNo() != details.nextToken.getLineNo();
+                && !TokenUtil.areOnSameLine(details.rcurly, details.nextToken);
     }
 
     /**
      * Checks that a right curly should be alone on a line.
+     *
      * @param bracePolicy option for placing the right curly brace
      * @param details Details for validation
      * @param targetSrcLine A string with contents of rcurly's line
@@ -230,6 +361,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
     /**
      * Whether right curly should be alone on line when ALONE option is used.
+     *
      * @param details details for validation.
      * @param targetSrcLine A string with contents of rcurly's line
      * @return true, if right curly should be alone on line when ALONE option is used.
@@ -241,6 +373,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
     /**
      * Whether right curly should be alone on line when ALONE_OR_SINGLELINE or SAME option is used.
+     *
      * @param details details for validation.
      * @param targetSrcLine A string with contents of rcurly's line
      * @return true, if right curly should be alone on line
@@ -254,6 +387,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
     /**
      * Checks whether right curly is alone on a line.
+     *
      * @param details for validation.
      * @param targetSrcLine A string with contents of rcurly's line
      * @return true if right curly is alone on a line.
@@ -261,7 +395,7 @@ public class RightCurlyCheck extends AbstractCheck {
     private static boolean isAloneOnLine(Details details, String targetSrcLine) {
         final DetailAST rcurly = details.rcurly;
         final DetailAST nextToken = details.nextToken;
-        return (rcurly.getLineNo() != nextToken.getLineNo() || skipDoubleBraceInstInit(details))
+        return (!TokenUtil.areOnSameLine(rcurly, nextToken) || skipDoubleBraceInstInit(details))
                 && CommonUtil.hasWhitespaceBefore(details.rcurly.getColumnNo(), targetSrcLine);
     }
 
@@ -293,6 +427,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
     /**
      * Checks whether block has a single-line format and is alone on a line.
+     *
      * @param details for validation.
      * @return true if block has single-line format and is alone on a line.
      */
@@ -307,13 +442,14 @@ public class RightCurlyCheck extends AbstractCheck {
             final DetailAST doWhileSemi = nextToken.getParent().getLastChild();
             nextToken = Details.getNextToken(doWhileSemi);
         }
-        return rcurly.getLineNo() == lcurly.getLineNo()
-                && (rcurly.getLineNo() != nextToken.getLineNo()
+        return TokenUtil.areOnSameLine(rcurly, lcurly)
+                && (!TokenUtil.areOnSameLine(rcurly, nextToken)
                 || isRightcurlyFollowedBySemicolon(details));
     }
 
     /**
      * Checks whether the right curly is followed by a semicolon.
+     *
      * @param details details for validation.
      * @return true if the right curly is followed by a semicolon.
      */
@@ -323,6 +459,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
     /**
      * Checks if right curly has line break before.
+     *
      * @param rightCurly right curly token.
      * @return true, if right curly has line break before.
      */
@@ -331,7 +468,7 @@ public class RightCurlyCheck extends AbstractCheck {
         if (previousToken == null) {
             previousToken = rightCurly.getParent();
         }
-        return rightCurly.getLineNo() != previousToken.getLineNo();
+        return !TokenUtil.areOnSameLine(rightCurly, previousToken);
     }
 
     /**
@@ -346,6 +483,7 @@ public class RightCurlyCheck extends AbstractCheck {
             TokenTypes.CLASS_DEF,
             TokenTypes.ENUM_DEF,
             TokenTypes.ANNOTATION_DEF,
+            TokenTypes.INTERFACE_DEF,
         };
 
         /** Right curly. */
@@ -359,6 +497,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
         /**
          * Constructor.
+         *
          * @param lcurly the lcurly of the token whose details are being collected
          * @param rcurly the rcurly of the token whose details are being collected
          * @param nextToken the token after the token whose details are being collected
@@ -374,6 +513,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
         /**
          * Collects validation Details.
+         *
          * @param ast a {@code DetailAST} value
          * @return object containing all details to make a validation
          */
@@ -403,6 +543,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
         /**
          * Collects validation details for LITERAL_TRY, LITERAL_CATCH, and LITERAL_FINALLY.
+         *
          * @param ast a {@code DetailAST} value
          * @return object containing all details to make a validation
          */
@@ -439,6 +580,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
         /**
          * Collects validation details for LITERAL_IF and LITERAL_ELSE.
+         *
          * @param ast a {@code DetailAST} value
          * @return object containing all details to make a validation
          */
@@ -467,6 +609,7 @@ public class RightCurlyCheck extends AbstractCheck {
         /**
          * Collects validation details for CLASS_DEF, METHOD DEF, CTOR_DEF, STATIC_INIT,
          * INSTANCE_INIT, ANNOTATION_DEF and ENUM_DEF.
+         *
          * @param ast a {@code DetailAST} value
          * @return an object containing all details to make a validation
          */
@@ -492,6 +635,7 @@ public class RightCurlyCheck extends AbstractCheck {
         /**
          * Tests whether the provided tokenType will never have a SLIST as child in its AST.
          * Like CLASS_DEF, ANNOTATION_DEF etc.
+         *
          * @param tokenType the tokenType to test against.
          * @return weather provided tokenType is definition token.
          */
@@ -501,6 +645,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
         /**
          * Collects validation details for loops' tokens.
+         *
          * @param ast a {@code DetailAST} value
          * @return an object containing all details to make a validation
          */
@@ -532,6 +677,7 @@ public class RightCurlyCheck extends AbstractCheck {
 
         /**
          * Finds next token after the given one.
+         *
          * @param ast the given node.
          * @return the token which represents next lexical item.
          */
