@@ -35,6 +35,27 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * <pre>
  * &lt;module name=&quot;MissingCtor&quot;/&gt;
  * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * class ExampleOk { // OK
+ *   private int a;
+ *   ExampleOk(int a) {
+ *     this.a = a;
+ *   }
+ * }
+ * class ExampleDefaultCtor { // OK
+ *   private String s;
+ *   ExampleDefaultCtor() {
+ *     s = "foobar";
+ *   }
+ * }
+ * class InvalidExample { // violation, class must have a constructor.
+ *   public void test() {}
+ * }
+ * abstract class AbstractExample { // OK
+ *   public abstract void test() {}
+ * }
+ * </pre>
  *
  * @since 3.4
  */
@@ -68,7 +89,7 @@ public class MissingCtorCheck extends AbstractCheck {
         if (modifiers.findFirstToken(TokenTypes.ABSTRACT) == null
                 && ast.findFirstToken(TokenTypes.OBJBLOCK)
                     .findFirstToken(TokenTypes.CTOR_DEF) == null) {
-            log(ast.getLineNo(), MSG_KEY);
+            log(ast, MSG_KEY);
         }
     }
 
