@@ -43,6 +43,26 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * <pre>
  * &lt;module name=&quot;MissingSwitchDefault&quot;/&gt;
  * </pre>
+ * <p>Example of violation:</p>
+ * <pre>
+ * switch (i) {    // violation
+ *  case 1:
+ *    break;
+ *  case 2:
+ *    break;
+ * }
+ * </pre>
+ * <p>Example of correct code:</p>
+ * <pre>
+ * switch (i) {
+ *  case 1:
+ *    break;
+ *  case 2:
+ *    break;
+ *  default: // OK
+ *    break;
+ * }
+ * </pre>
  *
  * @since 3.1
  */
@@ -75,12 +95,13 @@ public class MissingSwitchDefaultCheck extends AbstractCheck {
         final DetailAST firstCaseGroupAst = ast.findFirstToken(TokenTypes.CASE_GROUP);
 
         if (!containsDefaultSwitch(firstCaseGroupAst)) {
-            log(ast.getLineNo(), MSG_KEY);
+            log(ast, MSG_KEY);
         }
     }
 
     /**
      * Checks if the case group or its sibling contain the 'default' switch.
+     *
      * @param caseGroupAst first case group to check.
      * @return true if 'default' switch found.
      */
