@@ -226,6 +226,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
     /**
      * Setter to specify distance between declaration of variable and its first usage.
      * Values should be greater than 0.
+     *
      * @param allowedDistance
      *        Allowed distance between declaration of variable and its first
      *        usage.
@@ -236,6 +237,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
 
     /**
      * Setter to define RegExp to ignore distance calculation for variables listed in this pattern.
+     *
      * @param pattern a pattern.
      */
     public void setIgnoreVariablePattern(Pattern pattern) {
@@ -245,6 +247,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
     /**
      * Setter to allow to calculate the distance between declaration of
      * variable and its first usage in the different scopes.
+     *
      * @param validateBetweenScopes
      *        Defines if allow to calculate distance between declaration of
      *        variable and its first usage in different scopes or not.
@@ -255,6 +258,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
 
     /**
      * Setter to allow to ignore variables with a 'final' modifier.
+     *
      * @param ignoreFinal
      *        Defines if ignore variables with 'final' modifier or not.
      */
@@ -300,12 +304,10 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
                 if (dist > allowedDistance
                         && !isInitializationSequence(variableUsageAst, variable.getText())) {
                     if (ignoreFinal) {
-                        log(variable.getLineNo(),
-                                MSG_KEY_EXT, variable.getText(), dist, allowedDistance);
+                        log(ast, MSG_KEY_EXT, variable.getText(), dist, allowedDistance);
                     }
                     else {
-                        log(variable.getLineNo(),
-                                MSG_KEY, variable.getText(), dist, allowedDistance);
+                        log(ast, MSG_KEY, variable.getText(), dist, allowedDistance);
                     }
                 }
             }
@@ -314,6 +316,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
 
     /**
      * Get name of instance whose method is called.
+     *
      * @param methodCallAst
      *        DetailAST of METHOD_CALL.
      * @return name of instance.
@@ -332,6 +335,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
     /**
      * Processes statements until usage of variable to detect sequence of
      * initialization methods.
+     *
      * @param variableUsageAst
      *        DetailAST of expression that uses variable named variableName.
      * @param variableName
@@ -398,6 +402,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
     /**
      * Calculates distance between declaration of variable and its first usage
      * in single scope.
+     *
      * @param semicolonAst
      *        Regular node of Ast which is checked for content of checking
      *        variable.
@@ -437,6 +442,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
 
     /**
      * Returns the distance to variable usage for in the child node.
+     *
      * @param childNode child node.
      * @param varIdent variable variable identifier.
      * @param currentDistToVarUsage current distance to the variable usage.
@@ -485,6 +491,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
     /**
      * Calculates distance between declaration of variable and its first usage
      * in multiple scopes.
+     *
      * @param ast
      *        Regular node of Ast which is checked for content of checking
      *        variable.
@@ -564,6 +571,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
 
     /**
      * Searches variable usages starting from specified statement.
+     *
      * @param variableAst Variable that is used.
      * @param statementAst DetailAST to start searching from.
      * @return entry which contains list with found expressions that use the variable
@@ -595,6 +603,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
     /**
      * Gets first Ast node inside FOR, WHILE or DO-WHILE blocks if variable
      * usage is met only inside the block (not in its declaration!).
+     *
      * @param block
      *        Ast node represents FOR, WHILE or DO-WHILE block.
      * @param variable
@@ -637,6 +646,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
     /**
      * Gets first Ast node inside IF block if variable usage is met
      * only inside the block (not in its declaration!).
+     *
      * @param block
      *        Ast node represents IF block.
      * @param variable
@@ -698,6 +708,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
     /**
      * Gets first Ast node inside SWITCH block if variable usage is met
      * only inside the block (not in its declaration!).
+     *
      * @param block
      *        Ast node represents SWITCH block.
      * @param variable
@@ -739,6 +750,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
     /**
      * Gets first Ast node inside TRY-CATCH-FINALLY blocks if variable usage is
      * met only inside the block (not in its declaration!).
+     *
      * @param block
      *        Ast node represents TRY-CATCH-FINALLY block.
      * @param variable
@@ -801,6 +813,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
      * if (b) {...}
      * </pre>
      * Variable 'b' is in declaration of operator IF.
+     *
      * @param operator
      *        Ast node which represents operator.
      * @param variable
@@ -847,6 +860,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
 
     /**
      * Checks if Ast node contains given element.
+     *
      * @param parent
      *        Node of AST.
      * @param ast
@@ -881,6 +895,7 @@ public class VariableDeclarationUsageDistanceCheck extends AbstractCheck {
 
     /**
      * Checks if entrance variable is contained in ignored pattern.
+     *
      * @param variable
      *        Variable which is checked for content in ignored pattern.
      * @return true if variable was found, otherwise - false.
