@@ -53,6 +53,40 @@ import com.puppycrawl.tools.checkstyle.api.TokenTypes;
  * <pre>
  * &lt;module name="InterfaceIsType"/&gt;
  * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * public interface Test1 { // violation
+ *     int a = 3;
+ *
+ * }
+ *
+ * public interface Test2 { // OK
+ *
+ * }
+ *
+ * public interface Test3 { // OK
+ *     int a = 3;
+ *     void test();
+ * }
+ * </pre>
+ * <p>
+ * To configure the check to report violation so that it doesn't allow Marker Interfaces:
+ * </p>
+ * <pre>
+ * &lt;module name=&quot;InterfaceIsType&quot;&gt;
+ *   &lt;property name=&quot;allowMarkerInterfaces&quot; value=&quot;false&quot;/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * public interface Test1 { // violation
+ *     int a = 3;
+ * }
+ *
+ * public interface Test2 { // violation
+ *
+ * }
+ * </pre>
  *
  * @since 3.1
  */
@@ -96,12 +130,13 @@ public final class InterfaceIsTypeCheck
                 !allowMarkerInterfaces || variableDef != null;
 
         if (methodDef == null && methodRequired) {
-            log(ast.getLineNo(), MSG_KEY);
+            log(ast, MSG_KEY);
         }
     }
 
     /**
      * Setter to control whether marker interfaces like Serializable are allowed.
+     *
      * @param flag whether to allow marker interfaces or not
      */
     public void setAllowMarkerInterfaces(boolean flag) {
