@@ -1,6 +1,6 @@
 ////////////////////////////////////////////////////////////////////////////////
 // checkstyle: Checks Java source code for adherence to a set of rules.
-// Copyright (C) 2001-2018 the original author or authors.
+// Copyright (C) 2001-2020 the original author or authors.
 //
 // This library is free software; you can redistribute it and/or
 // modify it under the terms of the GNU Lesser General Public
@@ -79,21 +79,33 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
     /** Package names to ignore. */
     private static final Set<String> DEFAULT_EXCLUDED_PACKAGES = Collections.emptySet();
 
-    /** User-configured regular expressions to ignore classes. */
+    /** Specify user-configured regular expressions to ignore classes. */
     private final List<Pattern> excludeClassesRegexps = new ArrayList<>();
 
-    /** User-configured class names to ignore. */
+    /** A map of (imported class name -> class name with package) pairs. */
+    private final Map<String, String> importedClassPackages = new HashMap<>();
+
+    /** Stack of class contexts. */
+    private final Deque<ClassContext> classesContexts = new ArrayDeque<>();
+
+    /** Specify user-configured class names to ignore. */
     private Set<String> excludedClasses = DEFAULT_EXCLUDED_CLASSES;
-    /** User-configured package names to ignore. */
+
+    /**
+     * Specify user-configured packages to ignore. All excluded packages
+     * should end with a period, so it also appends a dot to a package name.
+     */
     private Set<String> excludedPackages = DEFAULT_EXCLUDED_PACKAGES;
-    /** Allowed complexity. */
+
+    /** Specify the maximum threshold allowed. */
     private int max;
 
-    /** Current file context. */
-    private FileContext fileContext;
+    /** Current file package. */
+    private String packageName;
 
     /**
      * Creates new instance of the check.
+     *
      * @param defaultMax default value for allowed complexity.
      */
     protected AbstractClassCouplingCheck(int defaultMax) {
@@ -103,6 +115,7 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
 
     /**
      * Returns message key we use for log violations.
+     *
      * @return message key we use for log violations.
      */
     protected abstract String getLogMessageId();
@@ -113,7 +126,8 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
     }
 
     /**
-     * Sets maximum allowed complexity.
+     * Setter to specify the maximum threshold allowed.
+     *
      * @param max allowed complexity.
      */
     public final void setMax(int max) {
@@ -121,7 +135,8 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
     }
 
     /**
-     * Sets user-excluded classes to ignore.
+     * Setter to specify user-configured class names to ignore.
+     *
      * @param excludedClasses the list of classes to ignore.
      */
     public final void setExcludedClasses(String... excludedClasses) {
@@ -130,7 +145,8 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
     }
 
     /**
-     * Sets user-excluded regular expression of classes to ignore.
+     * Setter to specify user-configured regular expressions to ignore classes.
+     *
      * @param from array representing regular expressions of classes to ignore.
      */
     public void setExcludeClassesRegexps(String... from) {
@@ -140,13 +156,14 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
     }
 
     /**
-     * Sets user-excluded packages to ignore. All excluded packages should end with a period,
-     * so it also appends a dot to a package name.
+     * Setter to specify user-configured packages to ignore. All excluded packages
+     * should end with a period, so it also appends a dot to a package name.
+     *
      * @param excludedPackages the list of packages to ignore.
      */
     public final void setExcludedPackages(String... excludedPackages) {
         final List<String> invalidIdentifiers = Arrays.stream(excludedPackages)
-            .filter(packageName -> !CommonUtil.isName(packageName))
+            .filter(excludedPackageName -> !CommonUtil.isName(excludedPackageName))
             .collect(Collectors.toList());
         if (!invalidIdentifiers.isEmpty()) {
             throw new IllegalArgumentException(
@@ -160,7 +177,10 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
 
     @Override
     public final void beginTree(DetailAST ast) {
-        fileContext = new FileContext();
+        importedClassPackages.clear();
+        classesContexts.clear();
+        classesContexts.push(new ClassContext("", null));
+        packageName = "";
     }
 
     @Override
@@ -170,7 +190,7 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
                 visitPackageDef(ast);
                 break;
             case TokenTypes.IMPORT:
-                fileContext.registerImport(ast);
+                registerImport(ast);
                 break;
             case TokenTypes.CLASS_DEF:
             case TokenTypes.INTERFACE_DEF:
@@ -181,16 +201,16 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
             case TokenTypes.EXTENDS_CLAUSE:
             case TokenTypes.IMPLEMENTS_CLAUSE:
             case TokenTypes.TYPE:
-                fileContext.visitType(ast);
+                visitType(ast);
                 break;
             case TokenTypes.LITERAL_NEW:
-                fileContext.visitLiteralNew(ast);
+                visitLiteralNew(ast);
                 break;
             case TokenTypes.LITERAL_THROWS:
-                fileContext.visitLiteralThrows(ast);
+                visitLiteralThrows(ast);
                 break;
             case TokenTypes.ANNOTATION:
-                fileContext.visitAnnotationType(ast);
+                visitAnnotationType(ast);
                 break;
             default:
                 throw new IllegalArgumentException("Unknown type: " + ast);
@@ -213,135 +233,93 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
 
     /**
      * Stores package of current class we check.
+     *
      * @param pkg package definition.
      */
     private void visitPackageDef(DetailAST pkg) {
         final FullIdent ident = FullIdent.createFullIdent(pkg.getLastChild().getPreviousSibling());
-        fileContext.setPackageName(ident.getText());
+        packageName = ident.getText();
     }
 
     /**
      * Creates new context for a given class.
+     *
      * @param classDef class definition node.
      */
     private void visitClassDef(DetailAST classDef) {
         final String className = classDef.findFirstToken(TokenTypes.IDENT).getText();
-        fileContext.createNewClassContext(className, classDef);
+        createNewClassContext(className, classDef);
     }
 
     /** Restores previous context. */
     private void leaveClassDef() {
-        fileContext.checkCurrentClassAndRestorePrevious();
+        checkCurrentClassAndRestorePrevious();
     }
 
     /**
-     * Encapsulates information about classes coupling inside single file.
-     * @noinspection ThisEscapedInObjectConstruction
+     * Registers given import. This allows us to track imported classes.
+     *
+     * @param imp import definition.
      */
-    private class FileContext {
+    private void registerImport(DetailAST imp) {
+        final FullIdent ident = FullIdent.createFullIdent(
+            imp.getLastChild().getPreviousSibling());
+        final String fullName = ident.getText();
+        final int lastDot = fullName.lastIndexOf(DOT);
+        importedClassPackages.put(fullName.substring(lastDot + 1), fullName);
+    }
 
-        /** A map of (imported class name -> class name with package) pairs. */
-        private final Map<String, String> importedClassPackage = new HashMap<>();
+    /**
+     * Creates new inner class context with given name and location.
+     *
+     * @param className The class name.
+     * @param ast The class ast.
+     */
+    private void createNewClassContext(String className, DetailAST ast) {
+        classesContexts.push(new ClassContext(className, ast));
+    }
 
-        /** Stack of class contexts. */
-        private final Deque<ClassContext> classesContexts = new ArrayDeque<>();
+    /** Restores previous context. */
+    private void checkCurrentClassAndRestorePrevious() {
+        classesContexts.pop().checkCoupling();
+    }
 
-        /** Current file package. */
-        private String packageName = "";
+    /**
+     * Visits type token for the current class context.
+     *
+     * @param ast TYPE token.
+     */
+    private void visitType(DetailAST ast) {
+        classesContexts.peek().visitType(ast);
+    }
 
-        /** Current context. */
-        private ClassContext classContext = new ClassContext(this, "", null);
+    /**
+     * Visits NEW token for the current class context.
+     *
+     * @param ast NEW token.
+     */
+    private void visitLiteralNew(DetailAST ast) {
+        classesContexts.peek().visitLiteralNew(ast);
+    }
 
-        /**
-         * Retrieves current file package name.
-         * @return Package name.
-         */
-        public String getPackageName() {
-            return packageName;
-        }
-
-        /**
-         * Sets current context package name.
-         * @param packageName Package name to be set.
-         */
-        public void setPackageName(String packageName) {
-            this.packageName = packageName;
-        }
-
-        /**
-         * Registers given import. This allows us to track imported classes.
-         * @param imp import definition.
-         */
-        public void registerImport(DetailAST imp) {
-            final FullIdent ident = FullIdent.createFullIdent(
-                imp.getLastChild().getPreviousSibling());
-            final String fullName = ident.getText();
-            if (fullName.charAt(fullName.length() - 1) != '*') {
-                final int lastDot = fullName.lastIndexOf(DOT);
-                importedClassPackage.put(fullName.substring(lastDot + 1), fullName);
-            }
-        }
-
-        /**
-         * Retrieves class name with packages. Uses previously registered imports to
-         * get the full class name.
-         * @param className Class name to be retrieved.
-         * @return Class name with package name, if found, {@link Optional#empty()} otherwise.
-         */
-        public Optional<String> getClassNameWithPackage(String className) {
-            return Optional.ofNullable(importedClassPackage.get(className));
-        }
-
-        /**
-         * Creates new inner class context with given name and location.
-         * @param className The class name.
-         * @param ast The class ast.
-         */
-        public void createNewClassContext(String className, DetailAST ast) {
-            classesContexts.push(classContext);
-            classContext = new ClassContext(this, className, ast);
-        }
-
-        /** Restores previous context. */
-        public void checkCurrentClassAndRestorePrevious() {
-            classContext.checkCoupling();
-            classContext = classesContexts.pop();
-        }
-
-        /**
-         * Visits type token for the current class context.
-         * @param ast TYPE token.
-         */
-        public void visitType(DetailAST ast) {
-            classContext.visitType(ast);
-        }
-
-        /**
-         * Visits NEW token for the current class context.
-         * @param ast NEW token.
-         */
-        public void visitLiteralNew(DetailAST ast) {
-            classContext.visitLiteralNew(ast);
-        }
-
-        /**
-         * Visits THROWS token for the current class context.
-         * @param ast THROWS token.
-         */
-        public void visitLiteralThrows(DetailAST ast) {
-            classContext.visitLiteralThrows(ast);
-        }
-
-        /**
-         * Visit ANNOTATION literal and get its type to referenced classes of context.
-         * @param annotationAST Annotation ast.
-         */
-        private void visitAnnotationType(DetailAST annotationAST) {
-            final DetailAST children = annotationAST.getFirstChild();
-            final DetailAST type = children.getNextSibling();
-            classContext.addReferencedClassName(type.getText());
-        }
+    /**
+     * Visits THROWS token for the current class context.
+     *
+     * @param ast THROWS token.
+     */
+    private void visitLiteralThrows(DetailAST ast) {
+        classesContexts.peek().visitLiteralThrows(ast);
+    }
 
+    /**
+     * Visit ANNOTATION literal and get its type to referenced classes of context.
+     *
+     * @param annotationAST Annotation ast.
+     */
+    private void visitAnnotationType(DetailAST annotationAST) {
+        final DetailAST children = annotationAST.getFirstChild();
+        final DetailAST type = children.getNextSibling();
+        classesContexts.peek().addReferencedClassName(type.getText());
     }
 
     /**
@@ -350,11 +328,9 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
      */
     private class ClassContext {
 
-        /** Parent file context. */
-        private final FileContext parentContext;
         /**
          * Set of referenced classes.
-         * Sorted by name for predictable error messages in unit tests.
+         * Sorted by name for predictable violation messages in unit tests.
          */
         private final Set<String> referencedClassNames = new TreeSet<>();
         /** Own class name. */
@@ -365,18 +341,18 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
 
         /**
          * Create new context associated with given class.
-         * @param parentContext Parent file context.
+         *
          * @param className name of the given class.
          * @param ast ast of class definition.
          */
-        ClassContext(FileContext parentContext, String className, DetailAST ast) {
-            this.parentContext = parentContext;
+        /* package */ ClassContext(String className, DetailAST ast) {
             this.className = className;
             classAst = ast;
         }
 
         /**
          * Visits throws clause and collects all exceptions we throw.
+         *
          * @param literalThrows throws to process.
          */
         public void visitLiteralThrows(DetailAST literalThrows) {
@@ -391,6 +367,7 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
 
         /**
          * Visits type.
+         *
          * @param ast type to process.
          */
         public void visitType(DetailAST ast) {
@@ -400,6 +377,7 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
 
         /**
          * Visits NEW.
+         *
          * @param ast NEW to process.
          */
         public void visitLiteralNew(DetailAST ast) {
@@ -408,6 +386,7 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
 
         /**
          * Adds new referenced class.
+         *
          * @param ast a node which represents referenced class.
          */
         private void addReferencedClassName(DetailAST ast) {
@@ -417,6 +396,7 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
 
         /**
          * Adds new referenced class.
+         *
          * @param referencedClassName class name of the referenced class.
          */
         private void addReferencedClassName(String referencedClassName) {
@@ -428,7 +408,7 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
         /** Checks if coupling less than allowed or not. */
         public void checkCoupling() {
             referencedClassNames.remove(className);
-            referencedClassNames.remove(parentContext.getPackageName() + DOT + className);
+            referencedClassNames.remove(packageName + DOT + className);
 
             if (referencedClassNames.size() > max) {
                 log(classAst, getLogMessageId(),
@@ -439,44 +419,67 @@ public abstract class AbstractClassCouplingCheck extends AbstractCheck {
 
         /**
          * Checks if given class shouldn't be ignored and not from java.lang.
+         *
          * @param candidateClassName class to check.
          * @return true if we should count this class.
          */
         private boolean isSignificant(String candidateClassName) {
-            boolean result = !excludedClasses.contains(candidateClassName)
-                && !isFromExcludedPackage(candidateClassName);
-            if (result) {
-                for (Pattern pattern : excludeClassesRegexps) {
-                    if (pattern.matcher(candidateClassName).matches()) {
-                        result = false;
-                        break;
-                    }
-                }
-            }
-            return result;
+            return !excludedClasses.contains(candidateClassName)
+                && !isFromExcludedPackage(candidateClassName)
+                && !isExcludedClassRegexp(candidateClassName);
         }
 
         /**
          * Checks if given class should be ignored as it belongs to excluded package.
+         *
          * @param candidateClassName class to check
          * @return true if we should not count this class.
          */
         private boolean isFromExcludedPackage(String candidateClassName) {
             String classNameWithPackage = candidateClassName;
             if (!candidateClassName.contains(DOT)) {
-                classNameWithPackage = parentContext.getClassNameWithPackage(candidateClassName)
+                classNameWithPackage = getClassNameWithPackage(candidateClassName)
                     .orElse("");
             }
             boolean isFromExcludedPackage = false;
             if (classNameWithPackage.contains(DOT)) {
                 final int lastDotIndex = classNameWithPackage.lastIndexOf(DOT);
-                final String packageName = classNameWithPackage.substring(0, lastDotIndex);
-                isFromExcludedPackage = packageName.startsWith("java.lang")
-                    || excludedPackages.contains(packageName);
+                final String candidatePackageName =
+                    classNameWithPackage.substring(0, lastDotIndex);
+                isFromExcludedPackage = candidatePackageName.startsWith("java.lang")
+                    || excludedPackages.contains(candidatePackageName);
             }
             return isFromExcludedPackage;
         }
 
+        /**
+         * Retrieves class name with packages. Uses previously registered imports to
+         * get the full class name.
+         *
+         * @param examineClassName Class name to be retrieved.
+         * @return Class name with package name, if found, {@link Optional#empty()} otherwise.
+         */
+        private Optional<String> getClassNameWithPackage(String examineClassName) {
+            return Optional.ofNullable(importedClassPackages.get(examineClassName));
+        }
+
+        /**
+         * Checks if given class should be ignored as it belongs to excluded class regexp.
+         *
+         * @param candidateClassName class to check.
+         * @return true if we should not count this class.
+         */
+        private boolean isExcludedClassRegexp(String candidateClassName) {
+            boolean result = false;
+            for (Pattern pattern : excludeClassesRegexps) {
+                if (pattern.matcher(candidateClassName).matches()) {
+                    result = true;
+                    break;
+                }
+            }
+            return result;
+        }
+
     }
 
 }
