@@ -50,6 +50,14 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * is what should be used to enforce strict camel casing. The identifier 'MyTest' would
  * be allowed, but 'MyTEst' would not be.
  * </p>
+ * <p>
+ * {@code ignoreFinal}, {@code ignoreStatic}, and {@code ignoreStaticFinal}
+ * control whether variables with the respective modifiers are to be ignored.
+ * Note that a variable that is both static and final will always be considered under
+ * {@code ignoreStaticFinal} only, regardless of the values of {@code ignoreFinal}
+ * and {@code ignoreStatic}. So for example if {@code ignoreStatic} is true but
+ * {@code ignoreStaticFinal} is false, then static final variables will not be ignored.
+ * </p>
  * <ul>
  * <li>
  * Property {@code allowedAbbreviationLength} - Indicate the number of consecutive capital
@@ -69,6 +77,10 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * value is {@code true}.
  * </li>
  * <li>
+ * Property {@code ignoreStaticFinal} - Allow to skip variables with both {@code static} and
+ * {@code final} modifiers. Default value is {@code true}.
+ * </li>
+ * <li>
  * Property {@code ignoreOverriddenMethods} - Allow to ignore methods tagged with {@code @Override}
  * annotation (that usually mean inherited name). Default value is {@code true}.
  * </li>
@@ -93,12 +105,69 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  * </li>
  * </ul>
  * <p>
- * Default configuration
+ * To configure the check:
  * </p>
  * <pre>
  * &lt;module name="AbbreviationAsWordInName"/&gt;
  * </pre>
  * <p>
+ * Example:
+ * </p>
+ * <pre>
+ * public class MyClass extends SuperClass { // OK, camel case
+ *   int CURRENT_COUNTER; // violation, at most 4 consecutive capital letters allowed
+ *   static int GLOBAL_COUNTER; // OK, static is ignored
+ *   final Set&lt;String&gt; stringsFOUND = new HashSet&lt;&gt;(); // OK, final is ignored
+ *
+ *   &#64;Override
+ *   void printCOUNTER() { // OK, overridden method is ignored
+ *     System.out.println(CURRENT_COUNTER); // OK, only definitions are checked
+ *   }
+ *
+ *   void incrementCOUNTER() { // violation, at most 4 consecutive capital letters allowed
+ *     CURRENT_COUNTER++; // OK, only definitions are checked
+ *   }
+ *
+ *   static void incrementGLOBAL() { // violation, static method is not ignored
+ *     GLOBAL_COUNTER++; // OK, only definitions are checked
+ *   }
+ *
+ * }
+ * </pre>
+ * <p>
+ * To configure to include static variables and methods tagged with
+ * {@code @Override} annotation.
+ * </p>
+ * <p>Configuration:</p>
+ * <pre>
+ * &lt;module name="AbbreviationAsWordInName"&gt;
+ *   &lt;property name="ignoreStatic" value="false"/&gt;
+ *   &lt;property name="ignoreOverriddenMethods" value="false"/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * public class MyClass extends SuperClass { // OK, camel case
+ *   int CURRENT_COUNTER; // violation, at most 4 consecutive capital letters allowed
+ *   static int GLOBAL_COUNTER; // violation, static is not ignored
+ *   final Set&lt;String&gt; stringsFOUND = new HashSet&lt;&gt;(); // OK, final is ignored
+ *
+ *   &#64;Override
+ *   void printCOUNTER() { // violation, overridden method is not ignored
+ *     System.out.println(CURRENT_COUNTER); // OK, only definitions are checked
+ *   }
+ *
+ *   void incrementCOUNTER() { // violation, at most 4 consecutive capital letters allowed
+ *     CURRENT_COUNTER++; // OK, only definitions are checked
+ *   }
+ *
+ *   static void incrementGLOBAL() { // violation, at most 4 consecutive capital letters allowed
+ *     GLOBAL_COUNTER++; // OK, only definitions are checked
+ *   }
+ *
+ * }
+ * </pre>
+ * <p>
  * To configure to check all variables and identifiers
  * (including ones with the static modifier) and enforce
  * no abbreviations (essentially camel case) except for
@@ -123,6 +192,8 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  *                         // and only 1 consecutive capital letter is allowed
  *   String firstXML; // OK, XML abbreviation is allowed
  *   String firstURL; // OK, URL abbreviation is allowed
+ *   final int TOTAL = 5; // OK, final is ignored
+ *   static final int LIMIT = 10; // OK, static final is ignored
  * }
  * </pre>
  * <p>
@@ -152,6 +223,54 @@ import com.puppycrawl.tools.checkstyle.utils.CommonUtil;
  *                         // would be ignored
  *   String firstCSV; // OK, CSV abbreviation is allowed
  *   String firstXML; // violation, XML abbreviation is not allowed
+ *   final int TOTAL = 5; // OK, final is ignored
+ *   static final int LIMIT = 10; // OK, static final is ignored
+ * }
+ * </pre>
+ * <p>
+ * To configure to check variables, enforcing no abbreviations
+ * except for variables that are both static and final.
+ * </p>
+ * <p>Configuration:</p>
+ * <pre>
+ * &lt;module name="AbbreviationAsWordInName"&gt;
+ *     &lt;property name="tokens" value="VARIABLE_DEF"/&gt;
+ *     &lt;property name="ignoreFinal" value="false"/&gt;
+ *     &lt;property name="ignoreStatic" value="false"/&gt;
+ *     &lt;property name="ignoreStaticFinal" value="true"/&gt;
+ *     &lt;property name="allowedAbbreviationLength" value="0"/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * public class MyClass {
+ *     public int counterXYZ = 1;                // violation
+ *     public final int customerID = 2;          // violation
+ *     public static int nextID = 3;             // violation
+ *     public static final int MAX_ALLOWED = 4;  // OK, ignored
+ * }
+ * </pre>
+ * <p>
+ * To configure to check variables, enforcing no abbreviations
+ * and ignoring static (but non-final) variables only.
+ * </p>
+ * <p>Configuration:</p>
+ * <pre>
+ * &lt;module name="AbbreviationAsWordInName"&gt;
+ *     &lt;property name="tokens" value="VARIABLE_DEF"/&gt;
+ *     &lt;property name="ignoreFinal" value="false"/&gt;
+ *     &lt;property name="ignoreStatic" value="true"/&gt;
+ *     &lt;property name="ignoreStaticFinal" value="false"/&gt;
+ *     &lt;property name="allowedAbbreviationLength" value="0"/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * public class MyClass {
+ *     public int counterXYZ = 1;                // violation
+ *     public final int customerID = 2;          // violation
+ *     public static int nextID = 3;             // OK, ignored
+ *     public static final int MAX_ALLOWED = 4;  // violation
  * }
  * </pre>
  *
@@ -190,6 +309,9 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
     /** Allow to skip variables with {@code static} modifier. */
     private boolean ignoreStatic = true;
 
+    /** Allow to skip variables with both {@code static} and {@code final} modifiers. */
+    private boolean ignoreStaticFinal = true;
+
     /**
      * Allow to ignore methods tagged with {@code @Override} annotation (that
      * usually mean inherited name).
@@ -198,6 +320,7 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
 
     /**
      * Setter to allow to skip variables with {@code final} modifier.
+     *
      * @param ignoreFinal
      *        Defines if ignore variables with 'final' modifier or not.
      */
@@ -207,6 +330,7 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
 
     /**
      * Setter to allow to skip variables with {@code static} modifier.
+     *
      * @param ignoreStatic
      *        Defines if ignore variables with 'static' modifier or not.
      */
@@ -214,9 +338,19 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
         this.ignoreStatic = ignoreStatic;
     }
 
+    /**
+     * Setter to allow to skip variables with both {@code static} and {@code final} modifiers.
+     * @param ignoreStaticFinal
+     *        Defines if ignore variables with both 'static' and 'final' modifiers or not.
+     */
+    public void setIgnoreStaticFinal(boolean ignoreStaticFinal) {
+        this.ignoreStaticFinal = ignoreStaticFinal;
+    }
+
     /**
      * Setter to allow to ignore methods tagged with {@code @Override}
      * annotation (that usually mean inherited name).
+     *
      * @param ignoreOverriddenMethods
      *        Defines if ignore methods with "@Override" annotation or not.
      */
@@ -228,6 +362,7 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
      * Setter to indicate the number of consecutive capital letters allowed
      * in targeted identifiers (abbreviations in the classes, interfaces,
      * variables and methods names, ... ).
+     *
      * @param allowedAbbreviationLength amount of allowed capital letters in
      *        abbreviation.
      */
@@ -238,6 +373,7 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
     /**
      * Setter to specify list of abbreviations that must be skipped for checking.
      * Abbreviations should be separated by comma.
+     *
      * @param allowedAbbreviations an string of abbreviations that must be
      *        skipped from checking, each abbreviation separated by comma.
      */
@@ -297,26 +433,22 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
 
     /**
      * Checks if it is an ignore situation.
+     *
      * @param ast input DetailAST node.
      * @return true if it is an ignore situation found for given input DetailAST
      *         node.
-     * @noinspection SimplifiableIfStatement
      */
     private boolean isIgnoreSituation(DetailAST ast) {
         final DetailAST modifiers = ast.getFirstChild();
 
         final boolean result;
         if (ast.getType() == TokenTypes.VARIABLE_DEF) {
-            if ((ignoreFinal || ignoreStatic)
-                    && isInterfaceDeclaration(ast)) {
+            if (isInterfaceDeclaration(ast)) {
                 // field declarations in interface are static/final
-                result = true;
+                result = ignoreStaticFinal;
             }
             else {
-                result = ignoreFinal
-                          && modifiers.findFirstToken(TokenTypes.FINAL) != null
-                    || ignoreStatic
-                        && modifiers.findFirstToken(TokenTypes.LITERAL_STATIC) != null;
+                result = hasIgnoredModifiers(modifiers);
             }
         }
         else if (ast.getType() == TokenTypes.METHOD_DEF) {
@@ -328,8 +460,27 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
         return result;
     }
 
+    /**
+     * Checks if a variable is to be ignored based on its modifiers.
+     * @param modifiers modifiers of the variable to be checked
+     * @return true if there is a modifier to be ignored
+     */
+    private boolean hasIgnoredModifiers(DetailAST modifiers) {
+        final boolean isStatic = modifiers.findFirstToken(TokenTypes.LITERAL_STATIC) != null;
+        final boolean isFinal = modifiers.findFirstToken(TokenTypes.FINAL) != null;
+        final boolean result;
+        if (isStatic && isFinal) {
+            result = ignoreStaticFinal;
+        }
+        else {
+            result = ignoreStatic && isStatic || ignoreFinal && isFinal;
+        }
+        return result;
+    }
+
     /**
      * Check that variable definition in interface or @interface definition.
+     *
      * @param variableDefAst variable definition.
      * @return true if variable definition(variableDefAst) is in interface
      *     or @interface definition.
@@ -348,6 +499,7 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
 
     /**
      * Checks that the method has "@Override" annotation.
+     *
      * @param methodModifiersAST
      *        A DetailAST nod is related to the given method modifiers
      *        (MODIFIERS type).
@@ -368,6 +520,7 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
 
     /**
      * Gets the disallowed abbreviation contained in given String.
+     *
      * @param str
      *        the given String.
      * @return the disallowed abbreviation contained in given String as a
@@ -409,6 +562,7 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
     /**
      * Get Abbreviation if it is illegal, where {@code beginIndex} and {@code endIndex} are
      * inclusive indexes of a sequence of consecutive upper-case characters.
+     *
      * @param str name
      * @param beginIndex begin index
      * @param endIndex end index
@@ -439,6 +593,7 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
      * For example, {@code getAbbreviation("getXMLParser", 3, 6)} returns "XML"
      * (not "XMLP"), and so does {@code getAbbreviation("parseXML", 5, 7)}.
      * </p>
+     *
      * @param str name
      * @param beginIndex begin index
      * @param endIndex end index
@@ -458,6 +613,7 @@ public class AbbreviationAsWordInNameCheck extends AbstractCheck {
     /**
      * Gets all the children which are one level below on the current DetailAST
      * parent node.
+     *
      * @param node
      *        Current parent node.
      * @return The list of children one level below on the current parent node.
