@@ -521,12 +521,7 @@ public class RegexpCheck extends AbstractCheck {
      * @param message custom message which should be used in report.
      */
     public void setMessage(String message) {
-        if (message == null) {
-            this.message = "";
-        }
-        else {
-            this.message = message;
-        }
+        this.message = message;
     }
 
     /**
@@ -631,6 +626,7 @@ public class RegexpCheck extends AbstractCheck {
 
     /**
      * Check if we can stop validation.
+     *
      * @param ignore flag
      * @return true is we can continue
      */
@@ -641,6 +637,7 @@ public class RegexpCheck extends AbstractCheck {
 
     /**
      * Detect ignore situation.
+     *
      * @param startLine position of line
      * @param text file text
      * @param start line column
@@ -668,6 +665,7 @@ public class RegexpCheck extends AbstractCheck {
 
     /**
      * Displays the right message.
+     *
      * @param lineNumber the line number the message relates to.
      */
     private void logMessage(int lineNumber) {
