@@ -46,6 +46,10 @@ import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
  * is required at its end (for example for CLASS_DEF it is after '}').
  * Also, trailing comments are skipped.
  * </p>
+ * <p>
+ * ATTENTION: violations from multiple empty lines cannot be suppressed via XPath:
+ * <a href="https://github.com/checkstyle/checkstyle/issues/8179">#8179</a>.
+ * </p>
  * <ul>
  * <li>
  * Property {@code allowNoEmptyLineBetweenFields} - Allow no empty line between fields.
@@ -234,6 +238,27 @@ import com.puppycrawl.tools.checkstyle.utils.JavadocUtil;
  *   }
  * }
  * </pre>
+ * <p>
+ * To disallow multiple empty lines between class members:
+ * </p>
+ *
+ * <pre>
+ * &lt;module name="EmptyLineSeparator"&gt;
+ *   &lt;property name="allowMultipleEmptyLines" value="false"/&gt;
+ * &lt;/module&gt;
+ * </pre>
+ * <p>Example:</p>
+ * <pre>
+ * package com.puppycrawl.tools.checkstyle.whitespace;
+ *
+ * class Test {
+ *     private int k;
+ *
+ *
+ *     private static void foo() {} // violation, before this like there two empty lines
+ *
+ * }
+ * </pre>
  *
  * @since 5.8
  */
@@ -283,6 +308,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Setter to allow no empty line between fields.
+     *
      * @param allow
      *        User's value.
      */
@@ -292,6 +318,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Setter to allow multiple empty lines between class members.
+     *
      * @param allow User's value.
      */
     public void setAllowMultipleEmptyLines(boolean allow) {
@@ -300,6 +327,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Setter to allow multiple empty lines inside class members.
+     *
      * @param allow User's value.
      */
     public void setAllowMultipleEmptyLinesInsideClassMembers(boolean allow) {
@@ -342,7 +370,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
     public void visitToken(DetailAST ast) {
         checkComments(ast);
         if (hasMultipleLinesBefore(ast)) {
-            log(ast.getLineNo(), MSG_MULTIPLE_LINES, ast.getText());
+            log(ast, MSG_MULTIPLE_LINES, ast.getText());
         }
         if (!allowMultipleEmptyLinesInsideClassMembers) {
             processMultipleLinesInside(ast);
@@ -381,11 +409,11 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
             default:
                 if (nextToken.getType() == TokenTypes.RCURLY) {
                     if (hasNotAllowedTwoEmptyLinesBefore(nextToken)) {
-                        log(ast.getLineNo(), MSG_MULTIPLE_LINES_AFTER, ast.getText());
+                        log(ast, MSG_MULTIPLE_LINES_AFTER, ast.getText());
                     }
                 }
                 else if (!hasEmptyLineAfter(ast)) {
-                    log(nextToken.getLineNo(), MSG_SHOULD_BE_SEPARATED,
+                    log(nextToken, MSG_SHOULD_BE_SEPARATED,
                         nextToken.getText());
                 }
         }
@@ -399,13 +427,14 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
     private void checkCommentInModifiers(DetailAST packageDef) {
         final Optional<DetailAST> comment = findCommentUnder(packageDef);
         if (comment.isPresent()) {
-            log(comment.get().getLineNo(), MSG_SHOULD_BE_SEPARATED, comment.get().getText());
+            log(comment.get(), MSG_SHOULD_BE_SEPARATED, comment.get().getText());
         }
     }
 
     /**
      * Log violation in case there are multiple empty lines inside constructor,
      * initialization block or method.
+     *
      * @param ast the ast to check.
      */
     private void processMultipleLinesInside(DetailAST ast) {
@@ -423,6 +452,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Whether the AST is a class member block.
+     *
      * @param astType the AST to check.
      * @return true if the AST is a class member block.
      */
@@ -435,6 +465,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Get list of empty lines.
+     *
      * @param ast the ast to check.
      * @return list of line numbers for empty lines.
      */
@@ -459,6 +490,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Get list of empty lines to log.
+     *
      * @param emptyLines list of empty lines.
      * @return list of empty lines to log.
      */
@@ -478,6 +510,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Whether the token has not allowed multiple empty lines before.
+     *
      * @param ast the ast to check.
      * @return true if the token has not allowed multiple empty lines before.
      */
@@ -493,6 +526,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Process Package.
+     *
      * @param ast token
      * @param nextToken next token
      */
@@ -500,45 +534,48 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
         if (ast.getLineNo() > 1 && !hasEmptyLineBefore(ast)) {
             if (getFileContents().getFileName().endsWith("package-info.java")) {
                 if (!ast.getFirstChild().hasChildren() && !isPrecededByJavadoc(ast)) {
-                    log(ast.getLineNo(), MSG_SHOULD_BE_SEPARATED, ast.getText());
+                    log(ast, MSG_SHOULD_BE_SEPARATED, ast.getText());
                 }
             }
             else {
-                log(ast.getLineNo(), MSG_SHOULD_BE_SEPARATED, ast.getText());
+                log(ast, MSG_SHOULD_BE_SEPARATED, ast.getText());
             }
         }
         if (!hasEmptyLineAfter(ast)) {
-            log(nextToken.getLineNo(), MSG_SHOULD_BE_SEPARATED, nextToken.getText());
+            log(nextToken, MSG_SHOULD_BE_SEPARATED, nextToken.getText());
         }
     }
 
     /**
      * Process Import.
+     *
      * @param ast token
      * @param nextToken next token
      */
     private void processImport(DetailAST ast, DetailAST nextToken) {
         if (nextToken.getType() != TokenTypes.IMPORT
                 && nextToken.getType() != TokenTypes.STATIC_IMPORT && !hasEmptyLineAfter(ast)) {
-            log(nextToken.getLineNo(), MSG_SHOULD_BE_SEPARATED, nextToken.getText());
+            log(nextToken, MSG_SHOULD_BE_SEPARATED, nextToken.getText());
         }
     }
 
     /**
      * Process Variable.
+     *
      * @param ast token
      * @param nextToken next Token
      */
     private void processVariableDef(DetailAST ast, DetailAST nextToken) {
         if (isTypeField(ast) && !hasEmptyLineAfter(ast)
                 && isViolatingEmptyLineBetweenFieldsPolicy(nextToken)) {
-            log(nextToken.getLineNo(), MSG_SHOULD_BE_SEPARATED,
+            log(nextToken, MSG_SHOULD_BE_SEPARATED,
                     nextToken.getText());
         }
     }
 
     /**
      * Checks whether token placement violates policy of empty line between fields.
+     *
      * @param detailAST token to be analyzed
      * @return true if policy is violated and warning should be raised; false otherwise
      */
@@ -550,6 +587,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Checks if a token has empty two previous lines and multiple empty lines is not allowed.
+     *
      * @param token DetailAST token
      * @return true, if token has empty two lines before and allowMultipleEmptyLines is false
      */
@@ -560,6 +598,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Check if group of comments located right before token has more than one previous empty line.
+     *
      * @param token DetailAST token
      */
     private void checkComments(DetailAST token) {
@@ -582,6 +621,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
     /**
      * Check if group of comments located at the start of token has more than one previous empty
      * line.
+     *
      * @param token DetailAST token
      */
     private void checkCommentsInsideToken(DetailAST token) {
@@ -611,6 +651,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Checks if a token has empty pre-previous line.
+     *
      * @param token DetailAST token.
      * @return true, if token has empty lines before.
      */
@@ -628,6 +669,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Checks if token have empty line after.
+     *
      * @param token token.
      * @return true if token have empty line after.
      */
@@ -664,6 +706,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
     /**
      * Checks, whether there are empty lines within the specified line range. Line numbering is
      * started from 1 for parameter values
+     *
      * @param startLine number of the first line in the range
      * @param endLine number of the second line in the range
      * @return {@code true} if found any blank line within the range, {@code false}
@@ -685,6 +728,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Checks if a token has a empty line before.
+     *
      * @param token token.
      * @return true, if token have empty line before.
      */
@@ -701,6 +745,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Check if token is comment, which starting in beginning of line.
+     *
      * @param comment comment token for check.
      * @return true, if token is comment, which starting in beginning of line.
      */
@@ -717,6 +762,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Check if token is preceded by javadoc comment.
+     *
      * @param token token for check.
      * @return true, if token is preceded by javadoc comment.
      */
@@ -732,6 +778,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * Check if token is a comment.
+     *
      * @param ast ast node
      * @return true, if given ast is comment.
      */
@@ -742,6 +789,7 @@ public class EmptyLineSeparatorCheck extends AbstractCheck {
 
     /**
      * If variable definition is a type field.
+     *
      * @param variableDef variable definition.
      * @return true variable definition is a type field.
      */
