@@ -49,6 +49,9 @@ public abstract class AbstractNode implements NodeInfo {
     /** The {@code TreeInfo} object. */
     private final TreeInfo treeInfo;
 
+    /** Depth of the node. */
+    private int depth;
+
     /**
      * Constructor of the abstract class {@code AbstractNode}.
      *
@@ -60,18 +63,37 @@ public abstract class AbstractNode implements NodeInfo {
 
     /**
      * Getter method for token type.
+     *
      * @return token type
      */
     public abstract int getTokenType();
 
     /**
      * Returns underlying node.
+     *
      * @return underlying node
      */
     public abstract DetailAST getUnderlyingNode();
 
+    /**
+     * Getter method for node depth.
+     * @return depth
+     */
+    public int getDepth() {
+        return depth;
+    }
+
+    /**
+     * Setter method for node depth.
+     * @param depth depth of node
+     */
+    public final void setDepth(int depth) {
+        this.depth = depth;
+    }
+
     /**
      * Getter method for children.
+     *
      * @return children list
      */
     protected List<AbstractNode> getChildren() {
@@ -80,6 +102,7 @@ public abstract class AbstractNode implements NodeInfo {
 
     /**
      * Add new child node to children list.
+     *
      * @param node child node
      */
     protected void addChild(AbstractNode node) {
@@ -88,6 +111,7 @@ public abstract class AbstractNode implements NodeInfo {
 
     /**
      * Returns true if nodes are same, false otherwise.
+     *
      * @param nodeInfo other node
      * @return {@code TreeInfo}
      */
@@ -98,6 +122,7 @@ public abstract class AbstractNode implements NodeInfo {
 
     /**
      * Returns if implementation provides fingerprints.
+     *
      * @return {@code boolean}
      */
     @Override
@@ -107,6 +132,7 @@ public abstract class AbstractNode implements NodeInfo {
 
     /**
      * Returns uri of the namespace for the current node.
+     *
      * @return uri
      */
     @Override
@@ -116,6 +142,7 @@ public abstract class AbstractNode implements NodeInfo {
 
     /**
      * Returns if current node has children.
+     *
      * @return if current node has children
      */
     @Override
@@ -125,6 +152,7 @@ public abstract class AbstractNode implements NodeInfo {
 
     /**
      * Determines axis iteration algorithm.
+     *
      * @param axisNumber element from {@code AxisInfo}
      * @param nodeTest filter for iterator
      * @return {@code AxisIterator} object
@@ -138,18 +166,9 @@ public abstract class AbstractNode implements NodeInfo {
         return axisIterator;
     }
 
-    /**
-     * Compares current object with specified for order.
-     * @param nodeInfo another {@code NodeInfo} object
-     * @return number representing order of current object to specified one
-     */
-    @Override
-    public int compareOrder(NodeInfo nodeInfo) {
-        return getLocalPart().compareTo(nodeInfo.getLocalPart());
-    }
-
     /**
      * Returns tree info.
+     *
      * @return tree info
      */
     @Override
@@ -157,205 +176,236 @@ public abstract class AbstractNode implements NodeInfo {
         return treeInfo;
     }
 
+    /**
+     * Returns string value. Throws {@code UnsupportedOperationException}, because no child
+     * class implements it and this method is not used for querying.
+     *
+     * @return string value
+     */
+    @Override
+    public String getStringValue() {
+        throw createUnsupportedOperationException();
+    }
+
     /**
      * Returns namespace array. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @param namespaceBindings namespace array
      * @return namespace array
      */
     @Override
     public final NamespaceBinding[] getDeclaredNamespaces(NamespaceBinding[] namespaceBindings) {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns boolean. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return boolean
      */
     @Override
     public final boolean isId() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns boolean. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return boolean
      */
     @Override
     public final boolean isIdref() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns boolean. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return boolean
      */
     @Override
     public final boolean isNilled() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns boolean. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return boolean
      */
     @Override
     public final boolean isStreamed() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns configuration. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return configuration
      */
     @Override
     public final Configuration getConfiguration() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Sets system id. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @param systemId system id
      */
     @Override
     public final void setSystemId(String systemId) {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns system id. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return system id
      */
     @Override
     public final String getSystemId() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns public id. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return public id
      */
     @Override
     public final String getPublicId() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns base uri. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return base uri
      */
     @Override
     public final String getBaseURI() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns location. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return location
      */
     @Override
     public final Location saveLocation() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns CharSequence string value. Throws {@code UnsupportedOperationException},
      * because no child class implements it and this method is not used for querying.
+     *
      * @return CharSequence string value
      */
     @Override
     public final CharSequence getStringValueCS() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns fingerprint. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return fingerprint
      */
     @Override
     public final int getFingerprint() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns display name. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return display name
      */
     @Override
     public final String getDisplayName() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns prefix. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return prefix
      */
     @Override
     public final String getPrefix() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns type of the schema. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return type of the schema
      */
     @Override
     public final SchemaType getSchemaType() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns AtomicSequence. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @return AtomicSequence
      */
     @Override
     public final AtomicSequence atomize() {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Generate id method. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @param fastStringBuffer fastStringBuffer
      */
     @Override
     public final void generateId(FastStringBuffer fastStringBuffer) {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Copy method. Throws {@code UnsupportedOperationException}, because no child
      * class implements it and this method is not used for querying.
+     *
      * @param receiver receiver
      * @param index index
      * @param location location
      */
     @Override
     public final void copy(Receiver receiver, int index, Location location) {
-        throw throwUnsupportedOperationException();
+        throw createUnsupportedOperationException();
     }
 
     /**
      * Returns UnsupportedOperationException exception. Methods which throws this exception are
      * not supported for all nodes.
+     *
      * @return UnsupportedOperationException exception
      */
-    private static UnsupportedOperationException throwUnsupportedOperationException() {
+    private static UnsupportedOperationException createUnsupportedOperationException() {
         return new UnsupportedOperationException("Operation is not supported");
     }
 
