@@ -48,9 +48,21 @@ public class AttributeNode extends AbstractNode {
         this.value = value;
     }
 
+    /**
+     * Compares current object with specified for order.
+     * Throws {@code UnsupportedOperationException} because functionality not required here.
+     * @param nodeInfo another {@code NodeInfo} object
+     * @return number representing order of current object to specified one
+     */
+    @Override
+    public int compareOrder(NodeInfo nodeInfo) {
+        throw throwUnsupportedOperationException();
+    }
+
     /**
      * Returns attribute value. Throws {@code UnsupportedOperationException} because attribute node
      * has no attributes.
+     *
      * @param namespace namespace
      * @param localPart actual name of the attribute
      * @return attribute value
@@ -62,6 +74,7 @@ public class AttributeNode extends AbstractNode {
 
     /**
      * Returns local part.
+     *
      * @return local part
      */
     @Override
@@ -71,6 +84,7 @@ public class AttributeNode extends AbstractNode {
 
     /**
      * Returns type of the node.
+     *
      * @return node kind
      */
     @Override
@@ -82,6 +96,7 @@ public class AttributeNode extends AbstractNode {
      * Returns parent.  Never called for attribute node, throws
      * {@code UnsupportedOperationException}.
      * has no attributes.
+     *
      * @return parent
      */
     @Override
@@ -92,6 +107,7 @@ public class AttributeNode extends AbstractNode {
     /**
      * Returns root. Never called for attribute node, throws
      * {@code UnsupportedOperationException}.
+     *
      * @return root
      */
     @Override
@@ -101,6 +117,7 @@ public class AttributeNode extends AbstractNode {
 
     /**
      * Returns string value.
+     *
      * @return string value
      */
     @Override
@@ -123,6 +140,7 @@ public class AttributeNode extends AbstractNode {
     /**
      * Returns line number. Attribute node has no line number, throws
      * {@code UnsupportedOperationException}.
+     *
      * @return line number
      */
     @Override
@@ -133,6 +151,7 @@ public class AttributeNode extends AbstractNode {
     /**
      * Returns column number. Attribute node has no column number, throws
      * {@code UnsupportedOperationException}.
+     *
      * @return column number
      */
     @Override
@@ -143,6 +162,7 @@ public class AttributeNode extends AbstractNode {
     /**
      * Getter method for token type. Attribute node has no token type, throws
      * {@code UnsupportedOperationException}.
+     *
      * @return token type
      */
     @Override
@@ -153,6 +173,7 @@ public class AttributeNode extends AbstractNode {
     /**
      * Returns underlying node. Attribute node has no underlying node, throws
      * {@code UnsupportedOperationException}.
+     *
      * @return underlying node
      */
     @Override
@@ -162,6 +183,7 @@ public class AttributeNode extends AbstractNode {
 
     /**
      * Returns UnsupportedOperationException exception.
+     *
      * @return UnsupportedOperationException exception
      */
     private static UnsupportedOperationException throwUnsupportedOperationException() {
