@@ -171,41 +171,43 @@ public class AvoidEscapedUnicodeCharactersCheckTest extends AbstractModuleTestSu
         final DefaultConfiguration checkConfig =
                 createModuleConfig(AvoidEscapedUnicodeCharactersCheck.class);
         final String[] expected = {
-            "7: " + getCheckMessage(MSG_KEY),
-            "9: " + getCheckMessage(MSG_KEY),
-            "11: " + getCheckMessage(MSG_KEY),
-            "15: " + getCheckMessage(MSG_KEY),
-            "16: " + getCheckMessage(MSG_KEY),
-            "20: " + getCheckMessage(MSG_KEY),
-            "24: " + getCheckMessage(MSG_KEY),
-            "25: " + getCheckMessage(MSG_KEY),
-            "27: " + getCheckMessage(MSG_KEY),
-            "31: " + getCheckMessage(MSG_KEY),
-            "32: " + getCheckMessage(MSG_KEY),
-            "33: " + getCheckMessage(MSG_KEY),
-            "34: " + getCheckMessage(MSG_KEY),
-            "42: " + getCheckMessage(MSG_KEY),
-            "59: " + getCheckMessage(MSG_KEY),
-            "60: " + getCheckMessage(MSG_KEY),
-            "61: " + getCheckMessage(MSG_KEY),
-            "62: " + getCheckMessage(MSG_KEY),
-            "72: " + getCheckMessage(MSG_KEY),
-            "73: " + getCheckMessage(MSG_KEY),
-            "74: " + getCheckMessage(MSG_KEY),
-            "75: " + getCheckMessage(MSG_KEY),
-            "76: " + getCheckMessage(MSG_KEY),
-            "77: " + getCheckMessage(MSG_KEY),
-            "79: " + getCheckMessage(MSG_KEY),
-            "82: " + getCheckMessage(MSG_KEY),
-            "86: " + getCheckMessage(MSG_KEY),
-            "87: " + getCheckMessage(MSG_KEY),
-            "88: " + getCheckMessage(MSG_KEY),
-            "89: " + getCheckMessage(MSG_KEY),
-            "92: " + getCheckMessage(MSG_KEY),
-            "93: " + getCheckMessage(MSG_KEY),
-            "94: " + getCheckMessage(MSG_KEY),
-            "98: " + getCheckMessage(MSG_KEY),
-            "104: " + getCheckMessage(MSG_KEY),
+            "7:38: " + getCheckMessage(MSG_KEY),
+            "9:38: " + getCheckMessage(MSG_KEY),
+            "11:38: " + getCheckMessage(MSG_KEY),
+            "15:38: " + getCheckMessage(MSG_KEY),
+            "16:38: " + getCheckMessage(MSG_KEY),
+            "20:24: " + getCheckMessage(MSG_KEY),
+            "24:36: " + getCheckMessage(MSG_KEY),
+            "25:36: " + getCheckMessage(MSG_KEY),
+            "27:24: " + getCheckMessage(MSG_KEY),
+            "31:38: " + getCheckMessage(MSG_KEY),
+            "32:38: " + getCheckMessage(MSG_KEY),
+            "33:38: " + getCheckMessage(MSG_KEY),
+            "34:47: " + getCheckMessage(MSG_KEY),
+            "42:32: " + getCheckMessage(MSG_KEY),
+            "59:35: " + getCheckMessage(MSG_KEY),
+            "60:35: " + getCheckMessage(MSG_KEY),
+            "61:35: " + getCheckMessage(MSG_KEY),
+            "62:35: " + getCheckMessage(MSG_KEY),
+            "72:24: " + getCheckMessage(MSG_KEY),
+            "73:24: " + getCheckMessage(MSG_KEY),
+            "74:24: " + getCheckMessage(MSG_KEY),
+            "75:24: " + getCheckMessage(MSG_KEY),
+            "76:24: " + getCheckMessage(MSG_KEY),
+            "77:24: " + getCheckMessage(MSG_KEY),
+            "79:24: " + getCheckMessage(MSG_KEY),
+            "82:31: " + getCheckMessage(MSG_KEY),
+            "82:48: " + getCheckMessage(MSG_KEY),
+            "86:38: " + getCheckMessage(MSG_KEY),
+            "87:38: " + getCheckMessage(MSG_KEY),
+            "88:38: " + getCheckMessage(MSG_KEY),
+            "89:38: " + getCheckMessage(MSG_KEY),
+            "92:31: " + getCheckMessage(MSG_KEY),
+            "92:45: " + getCheckMessage(MSG_KEY),
+            "93:34: " + getCheckMessage(MSG_KEY),
+            "94:46: " + getCheckMessage(MSG_KEY),
+            "98:38: " + getCheckMessage(MSG_KEY),
+            "104:38: " + getCheckMessage(MSG_KEY),
         };
         verify(checkConfig, getPath("InputAvoidEscapedUnicodeCharacters.java"), expected);
     }
@@ -216,37 +218,38 @@ public class AvoidEscapedUnicodeCharactersCheckTest extends AbstractModuleTestSu
                 createModuleConfig(AvoidEscapedUnicodeCharactersCheck.class);
         checkConfig.addAttribute("allowEscapesForControlCharacters", "true");
         final String[] expected = {
-            "7: " + getCheckMessage(MSG_KEY),
-            "9: " + getCheckMessage(MSG_KEY),
-            "11: " + getCheckMessage(MSG_KEY),
-            "15: " + getCheckMessage(MSG_KEY),
-            "16: " + getCheckMessage(MSG_KEY),
-            "24: " + getCheckMessage(MSG_KEY),
-            "25: " + getCheckMessage(MSG_KEY),
-            "31: " + getCheckMessage(MSG_KEY),
-            "32: " + getCheckMessage(MSG_KEY),
-            "33: " + getCheckMessage(MSG_KEY),
-            "34: " + getCheckMessage(MSG_KEY),
-            "42: " + getCheckMessage(MSG_KEY),
-            "59: " + getCheckMessage(MSG_KEY),
-            "60: " + getCheckMessage(MSG_KEY),
-            "61: " + getCheckMessage(MSG_KEY),
-            "62: " + getCheckMessage(MSG_KEY),
-            "73: " + getCheckMessage(MSG_KEY),
-            "74: " + getCheckMessage(MSG_KEY),
-            "75: " + getCheckMessage(MSG_KEY),
-            "76: " + getCheckMessage(MSG_KEY),
-            "77: " + getCheckMessage(MSG_KEY),
-            "79: " + getCheckMessage(MSG_KEY),
-            "82: " + getCheckMessage(MSG_KEY),
-            "86: " + getCheckMessage(MSG_KEY),
-            "87: " + getCheckMessage(MSG_KEY),
-            "88: " + getCheckMessage(MSG_KEY),
-            "89: " + getCheckMessage(MSG_KEY),
-            "92: " + getCheckMessage(MSG_KEY),
-            "94: " + getCheckMessage(MSG_KEY),
-            "98: " + getCheckMessage(MSG_KEY),
-            "104: " + getCheckMessage(MSG_KEY),
+            "7:38: " + getCheckMessage(MSG_KEY),
+            "9:38: " + getCheckMessage(MSG_KEY),
+            "11:38: " + getCheckMessage(MSG_KEY),
+            "15:38: " + getCheckMessage(MSG_KEY),
+            "16:38: " + getCheckMessage(MSG_KEY),
+            "24:36: " + getCheckMessage(MSG_KEY),
+            "25:36: " + getCheckMessage(MSG_KEY),
+            "31:38: " + getCheckMessage(MSG_KEY),
+            "32:38: " + getCheckMessage(MSG_KEY),
+            "33:38: " + getCheckMessage(MSG_KEY),
+            "34:47: " + getCheckMessage(MSG_KEY),
+            "42:32: " + getCheckMessage(MSG_KEY),
+            "59:35: " + getCheckMessage(MSG_KEY),
+            "60:35: " + getCheckMessage(MSG_KEY),
+            "61:35: " + getCheckMessage(MSG_KEY),
+            "62:35: " + getCheckMessage(MSG_KEY),
+            "73:24: " + getCheckMessage(MSG_KEY),
+            "74:24: " + getCheckMessage(MSG_KEY),
+            "75:24: " + getCheckMessage(MSG_KEY),
+            "76:24: " + getCheckMessage(MSG_KEY),
+            "77:24: " + getCheckMessage(MSG_KEY),
+            "79:24: " + getCheckMessage(MSG_KEY),
+            "82:31: " + getCheckMessage(MSG_KEY),
+            "82:48: " + getCheckMessage(MSG_KEY),
+            "86:38: " + getCheckMessage(MSG_KEY),
+            "87:38: " + getCheckMessage(MSG_KEY),
+            "88:38: " + getCheckMessage(MSG_KEY),
+            "89:38: " + getCheckMessage(MSG_KEY),
+            "92:45: " + getCheckMessage(MSG_KEY),
+            "94:46: " + getCheckMessage(MSG_KEY),
+            "98:38: " + getCheckMessage(MSG_KEY),
+            "104:38: " + getCheckMessage(MSG_KEY),
         };
         verify(checkConfig, getPath("InputAvoidEscapedUnicodeCharacters.java"), expected);
     }
@@ -257,26 +260,28 @@ public class AvoidEscapedUnicodeCharactersCheckTest extends AbstractModuleTestSu
                 createModuleConfig(AvoidEscapedUnicodeCharactersCheck.class);
         checkConfig.addAttribute("allowByTailComment", "true");
         final String[] expected = {
-            "7: " + getCheckMessage(MSG_KEY),
-            "15: " + getCheckMessage(MSG_KEY),
-            "24: " + getCheckMessage(MSG_KEY),
-            "31: " + getCheckMessage(MSG_KEY),
-            "33: " + getCheckMessage(MSG_KEY),
-            "34: " + getCheckMessage(MSG_KEY),
-            "59: " + getCheckMessage(MSG_KEY),
-            "60: " + getCheckMessage(MSG_KEY),
-            "61: " + getCheckMessage(MSG_KEY),
-            "62: " + getCheckMessage(MSG_KEY),
-            "73: " + getCheckMessage(MSG_KEY),
-            "74: " + getCheckMessage(MSG_KEY),
-            "75: " + getCheckMessage(MSG_KEY),
-            "76: " + getCheckMessage(MSG_KEY),
-            "77: " + getCheckMessage(MSG_KEY),
-            "79: " + getCheckMessage(MSG_KEY),
-            "82: " + getCheckMessage(MSG_KEY),
-            "92: " + getCheckMessage(MSG_KEY),
-            "98: " + getCheckMessage(MSG_KEY),
-            "104: " + getCheckMessage(MSG_KEY),
+            "15:38: " + getCheckMessage(MSG_KEY),
+            "7:38: " + getCheckMessage(MSG_KEY),
+            "24:36: " + getCheckMessage(MSG_KEY),
+            "31:38: " + getCheckMessage(MSG_KEY),
+            "33:38: " + getCheckMessage(MSG_KEY),
+            "34:47: " + getCheckMessage(MSG_KEY),
+            "59:35: " + getCheckMessage(MSG_KEY),
+            "60:35: " + getCheckMessage(MSG_KEY),
+            "61:35: " + getCheckMessage(MSG_KEY),
+            "62:35: " + getCheckMessage(MSG_KEY),
+            "73:24: " + getCheckMessage(MSG_KEY),
+            "74:24: " + getCheckMessage(MSG_KEY),
+            "75:24: " + getCheckMessage(MSG_KEY),
+            "76:24: " + getCheckMessage(MSG_KEY),
+            "77:24: " + getCheckMessage(MSG_KEY),
+            "79:24: " + getCheckMessage(MSG_KEY),
+            "82:31: " + getCheckMessage(MSG_KEY),
+            "82:48: " + getCheckMessage(MSG_KEY),
+            "92:31: " + getCheckMessage(MSG_KEY),
+            "92:45: " + getCheckMessage(MSG_KEY),
+            "98:38: " + getCheckMessage(MSG_KEY),
+            "104:38: " + getCheckMessage(MSG_KEY),
         };
         verify(checkConfig, getPath("InputAvoidEscapedUnicodeCharacters.java"), expected);
     }
@@ -287,20 +292,20 @@ public class AvoidEscapedUnicodeCharactersCheckTest extends AbstractModuleTestSu
                 createModuleConfig(AvoidEscapedUnicodeCharactersCheck.class);
         checkConfig.addAttribute("allowIfAllCharactersEscaped", "true");
         final String[] expected = {
-            "7: " + getCheckMessage(MSG_KEY),
-            "9: " + getCheckMessage(MSG_KEY),
-            "11: " + getCheckMessage(MSG_KEY),
-            "15: " + getCheckMessage(MSG_KEY),
-            "16: " + getCheckMessage(MSG_KEY),
-            "31: " + getCheckMessage(MSG_KEY),
-            "32: " + getCheckMessage(MSG_KEY),
-            "33: " + getCheckMessage(MSG_KEY),
-            "42: " + getCheckMessage(MSG_KEY),
-            "86: " + getCheckMessage(MSG_KEY),
-            "87: " + getCheckMessage(MSG_KEY),
-            "88: " + getCheckMessage(MSG_KEY),
-            "89: " + getCheckMessage(MSG_KEY),
-            "98: " + getCheckMessage(MSG_KEY),
+            "7:38: " + getCheckMessage(MSG_KEY),
+            "9:38: " + getCheckMessage(MSG_KEY),
+            "11:38: " + getCheckMessage(MSG_KEY),
+            "15:38: " + getCheckMessage(MSG_KEY),
+            "16:38: " + getCheckMessage(MSG_KEY),
+            "31:38: " + getCheckMessage(MSG_KEY),
+            "32:38: " + getCheckMessage(MSG_KEY),
+            "33:38: " + getCheckMessage(MSG_KEY),
+            "42:32: " + getCheckMessage(MSG_KEY),
+            "86:38: " + getCheckMessage(MSG_KEY),
+            "87:38: " + getCheckMessage(MSG_KEY),
+            "88:38: " + getCheckMessage(MSG_KEY),
+            "89:38: " + getCheckMessage(MSG_KEY),
+            "98:38: " + getCheckMessage(MSG_KEY),
         };
         verify(checkConfig, getPath("InputAvoidEscapedUnicodeCharacters.java"), expected);
     }
@@ -311,26 +316,26 @@ public class AvoidEscapedUnicodeCharactersCheckTest extends AbstractModuleTestSu
                 createModuleConfig(AvoidEscapedUnicodeCharactersCheck.class);
         checkConfig.addAttribute("allowNonPrintableEscapes", "true");
         final String[] expected = {
-            "7: " + getCheckMessage(MSG_KEY),
-            "9: " + getCheckMessage(MSG_KEY),
-            "11: " + getCheckMessage(MSG_KEY),
-            "15: " + getCheckMessage(MSG_KEY),
-            "16: " + getCheckMessage(MSG_KEY),
-            "24: " + getCheckMessage(MSG_KEY),
-            "25: " + getCheckMessage(MSG_KEY),
-            "31: " + getCheckMessage(MSG_KEY),
-            "32: " + getCheckMessage(MSG_KEY),
-            "33: " + getCheckMessage(MSG_KEY),
-            "34: " + getCheckMessage(MSG_KEY),
-            "42: " + getCheckMessage(MSG_KEY),
-            "86: " + getCheckMessage(MSG_KEY),
-            "87: " + getCheckMessage(MSG_KEY),
-            "88: " + getCheckMessage(MSG_KEY),
-            "89: " + getCheckMessage(MSG_KEY),
-            "93: " + getCheckMessage(MSG_KEY),
-            "94: " + getCheckMessage(MSG_KEY),
-            "98: " + getCheckMessage(MSG_KEY),
-            "104: " + getCheckMessage(MSG_KEY),
+            "7:38: " + getCheckMessage(MSG_KEY),
+            "9:38: " + getCheckMessage(MSG_KEY),
+            "11:38: " + getCheckMessage(MSG_KEY),
+            "15:38: " + getCheckMessage(MSG_KEY),
+            "16:38: " + getCheckMessage(MSG_KEY),
+            "24:36: " + getCheckMessage(MSG_KEY),
+            "25:36: " + getCheckMessage(MSG_KEY),
+            "31:38: " + getCheckMessage(MSG_KEY),
+            "32:38: " + getCheckMessage(MSG_KEY),
+            "33:38: " + getCheckMessage(MSG_KEY),
+            "34:47: " + getCheckMessage(MSG_KEY),
+            "42:32: " + getCheckMessage(MSG_KEY),
+            "86:38: " + getCheckMessage(MSG_KEY),
+            "87:38: " + getCheckMessage(MSG_KEY),
+            "88:38: " + getCheckMessage(MSG_KEY),
+            "89:38: " + getCheckMessage(MSG_KEY),
+            "93:34: " + getCheckMessage(MSG_KEY),
+            "94:46: " + getCheckMessage(MSG_KEY),
+            "98:38: " + getCheckMessage(MSG_KEY),
+            "104:38: " + getCheckMessage(MSG_KEY),
         };
         verify(checkConfig, getPath("InputAvoidEscapedUnicodeCharacters.java"), expected);
     }
@@ -354,7 +359,7 @@ public class AvoidEscapedUnicodeCharactersCheckTest extends AbstractModuleTestSu
         final String[] expected = IntStream.rangeClosed(0, 0xffff)
                 .parallel()
                 .filter(val -> !isControlCharacter(val))
-                .mapToObj(msg -> indexOfStartLineInInputFile + msg + ": " + message)
+                .mapToObj(msg -> indexOfStartLineInInputFile + msg + ":54: " + message)
                 .toArray(String[]::new);
         verify(checkConfig,
                 getPath("InputAvoidEscapedUnicodeCharactersAllEscapedUnicodeCharacters.java"),
