@@ -77,6 +77,7 @@ public class JavadocStyleCheckTest
             "63:11: " + getCheckMessage(MSG_UNCLOSED_HTML,
                 "<b>This guy is missing end of bold tag"),
             "66:7: " + getCheckMessage(MSG_EXTRA_HTML, "</td>Extra tag shouldn't be here"),
+            "67:49: " + getCheckMessage(MSG_EXTRA_HTML, "</style>"),
             "68:19: " + getCheckMessage(MSG_UNCLOSED_HTML, "<code>dummy."),
             "74: " + getCheckMessage(MSG_NO_PERIOD),
             "75:23: " + getCheckMessage(MSG_UNCLOSED_HTML, "<b>should fail"),
@@ -167,6 +168,7 @@ public class JavadocStyleCheckTest
             "63:11: " + getCheckMessage(MSG_UNCLOSED_HTML,
                 "<b>This guy is missing end of bold tag"),
             "66:7: " + getCheckMessage(MSG_EXTRA_HTML, "</td>Extra tag shouldn't be here"),
+            "67:49: " + getCheckMessage(MSG_EXTRA_HTML, "</style>"),
             "68:19: " + getCheckMessage(MSG_UNCLOSED_HTML, "<code>dummy."),
             "75:23: " + getCheckMessage(MSG_UNCLOSED_HTML, "<b>should fail"),
             "82:31: " + getCheckMessage(MSG_UNCLOSED_HTML, "<b>should fail"),
@@ -317,6 +319,7 @@ public class JavadocStyleCheckTest
             "63:11: " + getCheckMessage(MSG_UNCLOSED_HTML,
                 "<b>This guy is missing end of bold tag"),
             "66:7: " + getCheckMessage(MSG_EXTRA_HTML, "</td>Extra tag shouldn't be here"),
+            "67:49: " + getCheckMessage(MSG_EXTRA_HTML, "</style>"),
             "68:19: " + getCheckMessage(MSG_UNCLOSED_HTML, "<code>dummy."),
             "81: " + getCheckMessage(MSG_NO_PERIOD),
             "82:31: " + getCheckMessage(MSG_UNCLOSED_HTML, "<b>should fail"),
@@ -379,7 +382,7 @@ public class JavadocStyleCheckTest
         final DefaultConfiguration checkConfig =
             createModuleConfig(JavadocStyleCheck.class);
         final String[] expected = {
-            "1: " + getCheckMessage(MSG_JAVADOC_MISSING),
+            "1:1: " + getCheckMessage(MSG_JAVADOC_MISSING),
         };
 
         verify(checkConfig,
