@@ -52,15 +52,15 @@ public class EmptyLineSeparatorCheckTest
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
 
         final String[] expected = {
-            "21: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "import"),
-            "38: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
-            "41: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "VARIABLE_DEF"),
-            "42: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "STATIC_INIT"),
-            "46: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INSTANCE_INIT"),
-            "60: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CTOR_DEF"),
-            "65: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "METHOD_DEF"),
-            "82: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "METHOD_DEF"),
-            "113: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INTERFACE_DEF"),
+            "21:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "import"),
+            "38:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
+            "41:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "VARIABLE_DEF"),
+            "42:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "STATIC_INIT"),
+            "46:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INSTANCE_INIT"),
+            "60:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CTOR_DEF"),
+            "65:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "METHOD_DEF"),
+            "82:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "METHOD_DEF"),
+            "113:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INTERFACE_DEF"),
         };
         verify(checkConfig, getPath("InputEmptyLineSeparator.java"), expected);
     }
@@ -71,14 +71,14 @@ public class EmptyLineSeparatorCheckTest
         checkConfig.addAttribute("allowNoEmptyLineBetweenFields", "true");
 
         final String[] expected = {
-            "21: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "import"),
-            "38: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
-            "42: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "STATIC_INIT"),
-            "46: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INSTANCE_INIT"),
-            "60: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CTOR_DEF"),
-            "65: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "METHOD_DEF"),
-            "82: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "METHOD_DEF"),
-            "113: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INTERFACE_DEF"),
+            "21:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "import"),
+            "38:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
+            "42:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "STATIC_INIT"),
+            "46:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INSTANCE_INIT"),
+            "60:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CTOR_DEF"),
+            "65:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "METHOD_DEF"),
+            "82:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "METHOD_DEF"),
+            "113:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INTERFACE_DEF"),
         };
         verify(checkConfig, getPath("InputEmptyLineSeparator.java"), expected);
     }
@@ -87,7 +87,7 @@ public class EmptyLineSeparatorCheckTest
     public void testHeader() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "19: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
+            "19:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
         };
         verify(checkConfig, getPath("InputEmptyLineSeparatorHeader.java"), expected);
     }
@@ -97,13 +97,13 @@ public class EmptyLineSeparatorCheckTest
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         checkConfig.addAttribute("allowMultipleEmptyLines", "false");
         final String[] expected = {
-            "21: " + getCheckMessage(MSG_MULTIPLE_LINES, "package"),
-            "24: " + getCheckMessage(MSG_MULTIPLE_LINES, "import"),
-            "29: " + getCheckMessage(MSG_MULTIPLE_LINES, "CLASS_DEF"),
-            "33: " + getCheckMessage(MSG_MULTIPLE_LINES, "VARIABLE_DEF"),
-            "38: " + getCheckMessage(MSG_MULTIPLE_LINES, "VARIABLE_DEF"),
-            "43: " + getCheckMessage(MSG_MULTIPLE_LINES, "METHOD_DEF"),
-            "45: " + getCheckMessage(MSG_MULTIPLE_LINES_AFTER, "METHOD_DEF"),
+            "21:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "package"),
+            "24:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "import"),
+            "29:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "CLASS_DEF"),
+            "33:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "VARIABLE_DEF"),
+            "38:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "VARIABLE_DEF"),
+            "43:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "METHOD_DEF"),
+            "45:5: " + getCheckMessage(MSG_MULTIPLE_LINES_AFTER, "METHOD_DEF"),
         };
         verify(checkConfig, getPath("InputEmptyLineSeparatorMultipleEmptyLines.java"), expected);
     }
@@ -130,7 +130,7 @@ public class EmptyLineSeparatorCheckTest
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         checkConfig.addAttribute("allowMultipleEmptyLines", "false");
         final String[] expected = {
-            "1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "import"),
+            "1:78: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "import"),
         };
         verify(checkConfig, getPath("InputEmptyLineSeparatorMultipleImportEmptyClass.java"),
             expected);
@@ -150,7 +150,7 @@ public class EmptyLineSeparatorCheckTest
     public void testBlockCommentNotSeparatedFromPackage() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "12: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "/*"),
+            "12:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "/*"),
         };
         verify(checkConfig,
             getPath("InputEmptyLineSeparatorBlockCommentUnderPackage.java"),
@@ -161,7 +161,7 @@ public class EmptyLineSeparatorCheckTest
     public void testSingleCommentNotSeparatedFromPackage() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "12: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "//"),
+            "12:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "//"),
         };
         verify(checkConfig,
             getPath("InputEmptyLineSeparatorSingleCommentUnderPackage.java"),
@@ -172,7 +172,7 @@ public class EmptyLineSeparatorCheckTest
     public void testClassDefinitionNotSeparatedFromPackage() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "12: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
+            "12:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
         };
         verify(checkConfig,
             getPath("InputEmptyLineSeparatorModifierUnderPackage.java"),
@@ -183,8 +183,8 @@ public class EmptyLineSeparatorCheckTest
     public void testClassDefinitionAndCommentNotSeparatedFromPackage() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "12: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "//"),
-            "13: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
+            "12:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "//"),
+            "13:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
         };
         final String testFile =
             "InputEmptyLineSeparatorClassDefinitionAndCommentNotSeparatedFromPackage.java";
@@ -243,7 +243,7 @@ public class EmptyLineSeparatorCheckTest
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         checkConfig.addAttribute("allowMultipleEmptyLines", "false");
         final String[] expected = {
-            "3: " + getCheckMessage(MSG_MULTIPLE_LINES, "package"),
+            "3:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "package"),
         };
         verify(checkConfig,
                 getPath("InputEmptyLineSeparatorPrePreviousLineIsEmpty.java"), expected);
@@ -274,7 +274,7 @@ public class EmptyLineSeparatorCheckTest
             "50: " + getCheckMessage(MSG_MULTIPLE_LINES_INSIDE),
             "55: " + getCheckMessage(MSG_MULTIPLE_LINES_INSIDE),
             "56: " + getCheckMessage(MSG_MULTIPLE_LINES_INSIDE),
-            "60: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
+            "60:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
         };
         verify(checkConfig,
                 getPath("InputEmptyLineSeparatorMultipleEmptyLinesInside.java"),
@@ -285,7 +285,7 @@ public class EmptyLineSeparatorCheckTest
     public void testAllowMultipleEmptyLinesInsideClassMembers() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "60: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
+            "60:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
         };
         verify(checkConfig,
                 getPath("InputEmptyLineSeparatorMultipleEmptyLinesInside.java"),
@@ -321,7 +321,7 @@ public class EmptyLineSeparatorCheckTest
     public void testDisAllowBlockCommentBeforePackage() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "3: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
+            "3:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
         };
         verify(checkConfig,
                 getPath("packageinfo/test3/package-info.java"),
@@ -332,7 +332,7 @@ public class EmptyLineSeparatorCheckTest
     public void testAllowSingleLineCommentPackage() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "4: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
+            "4:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
         };
         verify(checkConfig,
                 getPath("packageinfo/test4/package-info.java"),
@@ -343,7 +343,7 @@ public class EmptyLineSeparatorCheckTest
     public void testNonPackageInfoWithJavadocBeforePackage() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "3: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
+            "3:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
         };
         verify(checkConfig,
                 getPath("InputEmptyLineSeparatorNonPackageInfoWithJavadocBeforePackage.java"),
@@ -356,7 +356,7 @@ public class EmptyLineSeparatorCheckTest
         checkConfig.addAttribute("tokens", "CLASS_DEF");
         checkConfig.addAttribute("allowMultipleEmptyLinesInsideClassMembers", "false");
         final String[] expected = {
-            "60: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
+            "60:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "CLASS_DEF"),
         };
         verify(checkConfig, getPath("InputEmptyLineSeparatorMultipleEmptyLinesInside.java"),
                 expected);
@@ -367,33 +367,33 @@ public class EmptyLineSeparatorCheckTest
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         checkConfig.addAttribute("allowMultipleEmptyLines", "false");
         final String[] expected = {
-            "19: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
+            "19:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
             "23:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
-            "27: " + getCheckMessage(MSG_MULTIPLE_LINES, "import"),
+            "27:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "import"),
             "32:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
             "39:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
             "50:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
             "67:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
             "78:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
-            "83: " + getCheckMessage(MSG_MULTIPLE_LINES, "import"),
+            "83:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "import"),
             "89:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
             "93:1: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
-            "101: " + getCheckMessage(MSG_MULTIPLE_LINES, "VARIABLE_DEF"),
+            "101:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "VARIABLE_DEF"),
             "106:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
             "113:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
             "126:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
-            "139: " + getCheckMessage(MSG_MULTIPLE_LINES, "METHOD_DEF"),
+            "139:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "METHOD_DEF"),
             "146:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
             "156:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
             "171:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
-            "188: " + getCheckMessage(MSG_MULTIPLE_LINES, "CLASS_DEF"),
+            "188:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "CLASS_DEF"),
             "194:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
             "198:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
             "204:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
             "216:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
             "229:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
             "243:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
-            "246: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INTERFACE_DEF"),
+            "246:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INTERFACE_DEF"),
             "251:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "/*"),
             "266:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
             "275:5: " + getCheckMessage(MSG_MULTIPLE_LINES, "//"),
@@ -413,8 +413,8 @@ public class EmptyLineSeparatorCheckTest
     public void testIgnoreEmptyLinesBeforeCommentsWhenItIsAllowed() throws Exception {
         final DefaultConfiguration checkConfig = createModuleConfig(EmptyLineSeparatorCheck.class);
         final String[] expected = {
-            "19: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
-            "246: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INTERFACE_DEF"),
+            "19:1: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "package"),
+            "246:5: " + getCheckMessage(MSG_SHOULD_BE_SEPARATED, "INTERFACE_DEF"),
         };
         verify(checkConfig, getPath("InputEmptyLineSeparatorWithComments.java"), expected);
     }
