@@ -239,7 +239,10 @@ public class AllChecksTest extends AbstractModuleTestSupport {
                 "COLON", "TYPE_EXTENSION_AND").collect(Collectors.toSet()));
         GOOGLE_TOKENS_IN_CONFIG_TO_IGNORE.put("NoWhitespaceBefore", Stream.of(
                 // google uses GenericWhitespace for this behavior
-                "GENERIC_START", "GENERIC_END").collect(Collectors.toSet()));
+                "GENERIC_START", "GENERIC_END",
+                // whitespace is necessary between a type annotation and ellipsis
+                // according '4.6.2 Horizontal whitespace point 9'
+                "ELLIPSIS").collect(Collectors.toSet()));
     }
 
     @Override
@@ -488,6 +491,11 @@ public class AllChecksTest extends AbstractModuleTestSupport {
         for (Class<?> module : CheckUtil.getCheckstyleChecks()) {
             final String name = module.getSimpleName();
 
+            // No messages in just module
+            if ("SuppressWarningsHolder".equals(name)) {
+                continue;
+            }
+
             assertFalse(CheckUtil.getCheckMessages(module).isEmpty(),
                     name + " should have at least one 'MSG_*' field for error messages");
         }
@@ -569,6 +577,7 @@ public class AllChecksTest extends AbstractModuleTestSupport {
 
     /**
      * Checks that an array is a subset of other array.
+     *
      * @param array to check whether it is a subset.
      * @param arrayToCheckIn array to check in.
      * @return {@code true} if all elements in {@code array} are in {@code arrayToCheckIn}.
