@@ -1,6 +1,6 @@
 package com.puppycrawl.tools.checkstyle.checks.design.visibilitymodifier;
 
-import com.puppycrawl.*;
+import com.puppycrawl.tools.checkstyle.*;
 
 public class InputVisibilityModifierIsStarImport {
 }
